Summary: The Linux kernel (the core of the Linux operating system)

# For a stable, released kernel, released_kernel should be 1. For rawhide
# and/or a kernel built from an rc or git snapshot, released_kernel should
# be 0.
%define released_kernel 1

# Versions of various parts

# Polite request for people who spin their own kernel rpms:
# please modify the "buildid" define in a way that identifies
# that the kernel isn't the stock distribution kernel, for example,
# by setting the define to ".local" or ".bz123456"
#
#% define buildid .local

# fedora_build defines which build revision of this kernel version we're
# building. Rather than incrementing forever, as with the prior versioning
# setup, we set fedora_cvs_origin to the current cvs revision s/1.// of the
# kernel spec when the kernel is rebased, so fedora_build automatically
# works out to the offset from the rebase, so it doesn't get too ginormous.
#
%define fedora_cvs_origin 39
%define fedora_build %(R="$Revision: 1.41 $"; R="${R%% \$}"; R="${R##: 1.}"; expr $R - %{fedora_cvs_origin})

# base_sublevel is the kernel version we're starting with and patching
# on top of -- for example, 2.6.22-rc7-git1 starts with a 2.6.21 base,
# which yields a base_sublevel of 21.
%define base_sublevel 25

## If this is a released kernel ##
%if 0%{?released_kernel}
# Do we have a 2.6.21.y update to apply?
%define stable_update 0
# Set rpm version accordingly
%if 0%{?stable_update}
%define stablerev .%{stable_update}
%endif
%define rpmversion 2.6.%{base_sublevel}%{?stablerev}

## The not-released-kernel case ##
%else
# The next upstream release sublevel (base_sublevel+1)
%define upstream_sublevel %(expr %{base_sublevel} + 1)
# The rc snapshot level
%define rcrev 0
# The git snapshot level
%define gitrev 0
# Set rpm version accordingly
%define rpmversion 2.6.%{upstream_sublevel}
%endif
# Nb: The above rcrev and gitrev values automagically define Patch00 and Patch01 below.

# What parts do we want to build?  We must build at least one kernel.
# These are the kernels that are built IF the architecture allows it.
# All should default to 1 (enabled) and be flipped to 0 (disabled)
# by later arch-specific checks.

# The following build options are enabled by default.
# Use either --without <opt> in your rpmbuild command or force values
# to 0 in here to disable them.
#
# standard kernel
%define with_up        %{?_without_up:        0} %{?!_without_up:        1}
# kernel-smp (only valid for ppc 32-bit, sparc64)
%define with_smp       %{?_without_smp:       0} %{?!_without_smp:       1}
# kernel-PAE (only valid for i686)
%define with_pae       %{?_without_pae:       0} %{?!_without_pae:       1}
# kernel-xen
%define with_xen       %{?_without_xen:       0} %{?!_without_xen:       1}
# kernel-kdump
%define with_kdump     %{?_without_kdump:     0} %{?!_without_kdump:     1}
# kernel-debug
%define with_debug     %{?_without_debug:     0} %{!?_without_debug:     1}
# kernel-doc
%define with_doc       %{?_without_doc:       0} %{?!_without_doc:       1}
# kernel-headers
%define with_headers   %{?_without_headers:   0} %{?!_without_headers:   1}
# kernel-debuginfo
%define with_debuginfo %{?_without_debuginfo: 0} %{!?_without_debuginfo: 1}
# kernel-bootwrapper (for creating zImages from kernel + initrd)
%define with_bootwrapper %{?_without_bootwrapper: 0} %{!?_without_bootwrapper: 1}

# Additional options for user-friendly one-off kernel building:
#
# Only build the base kernel (--with baseonly):
%define with_baseonly  %{?_with_baseonly:     1} %{?!_with_baseonly:     0}
# Only build the smp kernel (--with smponly):
%define with_smponly   %{?_with_smponly:      1} %{?!_with_smponly:      0}
# Only build the pae kernel (--with paeonly):
%define with_paeonly   %{?_with_paeonly:      1} %{?!_with_paeonly:      0}
# Only build the xen kernel (--with xenonly):
%define with_xenonly   %{?_with_xenonly:      1} %{?!_with_xenonly:      0}

# should we do C=1 builds with sparse
%define with_sparse	%{?_with_sparse:      1} %{?!_with_sparse:      0}

# Whether or not to apply the Xen patches -- leave this enabled
%define includexen 1
# Disable non-xen sub-packages under kernel-xen-2.6
%define with_xenonly 1
%define with_headers 0

# Set debugbuildsenabled to 1 for production (build separate debug kernels)
#  and 0 for rawhide (all kernels are debug kernels).
# See also 'make debug' and 'make release'.
%define debugbuildsenabled 1

# Want to build a vanilla kernel build without any non-upstream patches?
# (well, almost none, we need nonintconfig for build purposes). Default to 0 (off).
%define with_vanilla %{?_with_vanilla: 1} %{?!_with_vanilla: 0}

# pkg_release is what we'll fill in for the rpm Release: field
%if 0%{?released_kernel}
%define pkg_release %{fedora_build}%{?buildid}%{?dist}
%else
%if 0%{?rcrev}
%define rctag .rc%rcrev
%endif
%if 0%{?gitrev}
%define gittag .git%gitrev
%if !0%{?rcrev}
%define rctag .rc0
%endif
%endif
%define pkg_release 0.%{fedora_build}%{?rctag}%{?gittag}%{?buildid}%{?dist}
%endif

%define mainpkgname kernel-xen-2.6
%if !0%{?variantbase:1}
%define variantbase kernel
%endif

# The kernel tarball/base version
%define kversion 2.6.%{base_sublevel}

%define make_target bzImage

%define xen_hv_version 3.2.0
%define xen_hv_dirname xen-%{xen_hv_version}
%define xen_flags verbose=y crash_debug=y
%define xen_target vmlinuz
%define xen_image arch/x86/boot/vmlinuz

%define KVERREL %{PACKAGE_VERSION}-%{PACKAGE_RELEASE}.%{_target_cpu}
%define hdrarch %_target_cpu

%if 0%{!?nopatches:1}
%define nopatches 0
%endif

%if %{with_vanilla}
%define nopatches 1
%endif

%if %{nopatches}
%define includexen 0
%define with_xen 0
%define with_bootwrapper 0
%define variant -vanilla
%else
%define variant_fedora -fedora
%endif

%define using_upstream_branch 0
%if 0%{?upstream_branch:1}
%define stable_update 0
%define using_upstream_branch 1
%define variant -%{upstream_branch}%{?variant_fedora}
%define pkg_release 0.%{fedora_build}%{upstream_branch_tag}%{?buildid}%{?dist}
%endif

%if !%{debugbuildsenabled}
%define with_debug 0
%endif

%if !%{with_debuginfo}
%define _enable_debug_packages 0
%endif
%define debuginfodir /usr/lib/debug

# if requested, only build base kernel
%if %{with_baseonly}
%define with_smp 0
%define with_pae 0
%define with_xen 0
%define with_kdump 0
%define with_debug 0
%endif

# if requested, only build smp kernel
%if %{with_smponly}
%define with_up 0
%define with_pae 0
%define with_xen 0
%define with_kdump 0
%define with_debug 0
%endif

# if requested, only build pae kernel
%if %{with_paeonly}
%define with_up 0
%define with_smp 0
%define with_xen 0
%define with_kdump 0
%define with_debug 0
%endif

# if requested, only build xen kernel
%if %{with_xenonly}
%define with_up 0
%define with_smp 0
%define with_pae 0
%define with_kdump 0
%define with_debug 0
%endif

%define all_x86 i386 i586 i686

# These arches install vdso/ directories.
%define vdso_arches %{all_x86} x86_64 ppc ppc64

# Overrides for generic default options

# only ppc and sparc64 need separate smp kernels
%ifnarch ppc sparc64 alphaev56
%define with_smp 0
%endif

# pae is only valid on i686
%ifnarch i686
%define with_pae 0
%endif

# xen only builds on i686 and x86_64
%ifnarch i686 x86_64
%define with_xen 0
%endif

# only build kernel-kdump on ppc64
# (no relocatable kernel support upstream yet)
%ifnarch ppc64
%define with_kdump 0
%endif

# don't do debug builds on anything but i686 and x86_64
%ifnarch i686 x86_64
%define with_debug 0
%endif

# only package docs noarch
%ifnarch noarch
%define with_doc 0
%endif

# no need to build headers again for these arches,
# they can just use i386 and ppc64 headers
%ifarch i586 i686 ppc64iseries
%define with_headers 0
%endif

# don't build noarch kernels or headers (duh)
%ifarch noarch
%define with_up 0
%define with_headers 0
%define all_arch_configs kernel-%{version}-*.config
%endif

# bootwrapper is only on ppc
%ifnarch ppc ppc64
%define with_bootwrapper 0
%endif

# sparse blows up on ppc64 alpha and sparc64
%ifarch ppc64 ppc alpha sparc64
%define with_sparse 0
%endif

# Per-arch tweaks

%ifarch %{all_x86}
%define all_arch_configs kernel-%{version}-i?86*.config
%define image_install_path boot
%define hdrarch i386
# we build always xen i686 HV with pae
%define xen_flags verbose=y crash_debug=y pae=y
%define kernel_image arch/x86/boot/bzImage
%endif

%ifarch x86_64
%define all_arch_configs kernel-%{version}-x86_64*.config
%define image_install_path boot
%define kernel_image arch/x86/boot/bzImage
%endif

%ifarch ppc64
%define all_arch_configs kernel-%{version}-ppc64*.config
%define image_install_path boot
%define make_target vmlinux
%define kernel_image vmlinux
%define kernel_image_elf 1
%define hdrarch powerpc
%endif

%ifarch s390x
%define all_arch_configs kernel-%{version}-s390x.config
%define image_install_path boot
%define make_target image
%define kernel_image arch/s390/boot/image
%define hdrarch s390
%endif

%ifarch sparc
# We only build sparc headers since we dont support sparc32 hardware
%endif

%ifarch sparc64
%define all_arch_configs kernel-%{version}-sparc64*.config
%define make_target image
%define kernel_image arch/sparc64/boot/image
%define image_install_path boot
%endif

%ifarch ppc
%define all_arch_configs kernel-%{version}-ppc{-,.}*config
%define image_install_path boot
%define make_target vmlinux
%define kernel_image vmlinux
%define kernel_image_elf 1
%define hdrarch powerpc
%endif

%ifarch ia64
%define all_arch_configs kernel-%{version}-ia64*.config
%define image_install_path boot/efi/EFI/redhat
%define make_target compressed
%define kernel_image vmlinux.gz
# ia64 xen HV doesn't building with debug=y at the moment
%define xen_flags verbose=y crash_debug=y
%define xen_target compressed
%define xen_image vmlinux.gz
%endif

%ifarch alpha alphaev56
%define all_arch_configs kernel-%{version}-alpha*.config
%define image_install_path boot
%define make_target vmlinux
%define kernel_image vmlinux
%endif

%if %{nopatches}
# XXX temporary until last vdso patches are upstream
%define vdso_arches ppc ppc64
%endif

%if %{nopatches}%{using_upstream_branch}
# Ignore unknown options in our config-* files.
# Some options go with patches we're not applying.
%define oldconfig_target loose_nonint_oldconfig
%else
%define oldconfig_target nonint_oldconfig
%endif

# To temporarily exclude an architecture from being built, add it to
# %nobuildarches. Do _NOT_ use the ExclusiveArch: line, because if we
# don't build kernel-headers then the new build system will no longer let
# us use the previous build of that package -- it'll just be completely AWOL.
# Which is a BadThing(tm).

# We don't build a kernel on i386; we only do kernel-headers there,
# and we no longer build for 31bit S390. Same for 32bit sparc.
%define nobuildarches i386 s390 sparc

%ifarch %nobuildarches
%define with_up 0
%define with_smp 0
%define with_pae 0
%define with_xen 0
%define with_kdump 0
%define with_debuginfo 0
%define _enable_debug_packages 0
%endif

%define with_pae_debug 0
%if %with_pae
%define with_pae_debug %{with_debug}
%endif

#
# Three sets of minimum package version requirements in the form of Conflicts:
# to versions below the minimum
#

#
# First the general kernel 2.6 required versions as per
# Documentation/Changes
#
%define kernel_dot_org_conflicts  ppp < 2.4.3-3, isdn4k-utils < 3.2-32, nfs-utils < 1.0.7-12, e2fsprogs < 1.37-4, util-linux < 2.12, jfsutils < 1.1.7-2, reiserfs-utils < 3.6.19-2, xfsprogs < 2.6.13-4, procps < 3.2.5-6.3, oprofile < 0.9.1-2

#
# Then a series of requirements that are distribution specific, either
# because we add patches for something, or the older versions have
# problems with the newer kernel or lack certain things that make
# integration in the distro harder than needed.
#
%define package_conflicts initscripts < 7.23, udev < 063-6, iptables < 1.3.2-1, ipw2200-firmware < 2.4, selinux-policy-targeted < 1.25.3-14

#
# The ld.so.conf.d file we install uses syntax older ldconfig's don't grok.
#
%define kernel_xen_conflicts glibc < 2.3.5-1, xen < 3.0.1

# xen-hypervisor-abi provides (bug #269581)
%define kernel_xen_provides xen-hypervisor-abi = 3.2

# upto and including kernel 2.4.9 rpms, the 4Gb+ kernel was called kernel-enterprise
# now that the smp kernel offers this capability, obsolete the old kernel
%define kernel_smp_obsoletes kernel-enterprise < 2.4.10
%define kernel_PAE_obsoletes kernel-smp < 2.6.17

#
# Packages that need to be installed before the kernel is, because the %post
# scripts use them.
#
%define kernel_prereq  fileutils, module-init-tools, initscripts >= 8.11.1-1, mkinitrd >= 6.0.39-1

#
# This macro does requires, provides, conflicts, obsoletes for a kernel package.
#	%%kernel_reqprovconf <subpackage>
# It uses any kernel_<subpackage>_conflicts and kernel_<subpackage>_obsoletes
# macros defined above.
#
%define kernel_reqprovconf \
Provides: kernel = %{rpmversion}-%{pkg_release}\
Provides: kernel-%{_target_cpu} = %{rpmversion}-%{pkg_release}%{?1:.%{1}}\
Provides: kernel-drm = 4.3.0\
Provides: kernel-drm-nouveau = 10\
Provides: kernel-modeset = 1\
Provides: kernel-uname-r = %{KVERREL}%{?1:.%{1}}\
Requires(pre): %{kernel_prereq}\
Conflicts: %{kernel_dot_org_conflicts}\
Conflicts: %{package_conflicts}\
%{?1:%{expand:%%{?kernel_%{1}_conflicts:Conflicts: %%{kernel_%{1}_conflicts}}}}\
%{?1:%{expand:%%{?kernel_%{1}_obsoletes:Obsoletes: %%{kernel_%{1}_obsoletes}}}}\
%{?1:%{expand:%%{?kernel_%{1}_provides:Provides: %%{kernel_%{1}_provides}}}}\
# We can't let RPM do the dependencies automatic because it'll then pick up\
# a correct but undesirable perl dependency from the module headers which\
# isn't required for the kernel proper to function\
AutoReq: no\
AutoProv: yes\
%{nil}

Name: %{mainpkgname}
Group: System Environment/Kernel
License: GPLv2
URL: http://www.kernel.org/
Version: %{rpmversion}
Release: %{pkg_release}
# DO NOT CHANGE THE 'ExclusiveArch' LINE TO TEMPORARILY EXCLUDE AN ARCHITECTURE BUILD.
# SET %%nobuildarches (ABOVE) INSTEAD
ExclusiveArch: noarch i686 x86_64
ExclusiveOS: Linux

%kernel_reqprovconf
%ifarch x86_64
Obsoletes: kernel-smp
%endif


#
# List the packages used during the kernel build
#
BuildRequires: module-init-tools, patch >= 2.5.4, bash >= 2.03, sh-utils, tar
BuildRequires: bzip2, findutils, gzip, m4, perl, make >= 3.78, diffutils, gawk
BuildRequires: gcc >= 3.4.2, binutils >= 2.12, redhat-rpm-config
%if %{with_doc}
BuildRequires: xmlto
%endif
%if %{with_sparse}
BuildRequires: sparse >= 0.4.1
%endif
BuildConflicts: rhbuildsys(DiskFree) < 500Mb

# needed for xen mkheader.py
BuildRequires: python

%define fancy_debuginfo 0
%if %{with_debuginfo}
%if "%fedora" > "7"
%define fancy_debuginfo 1
%endif
%endif

%if %{fancy_debuginfo}
# Fancy new debuginfo generation introduced in Fedora 8.
BuildRequires: rpm-build >= 4.4.2.1-4
%define debuginfo_args --strict-build-id
%endif

Source0: ftp://ftp.kernel.org/pub/linux/kernel/v2.6/linux-%{kversion}.tar.bz2
Source1: xen-%{xen_hv_version}.tar.gz
Source2: Config.mk

Source10: COPYING.modules
Source11: genkey
Source14: find-provides
Source15: merge.pl

Source20: Makefile.config
Source21: config-debug
Source22: config-nodebug
Source23: config-generic
Source24: config-xen-generic
Source25: config-rhel-generic
Source26: config-rhel-x86-generic

Source30: config-x86-generic
Source31: config-i586
Source32: config-i686
Source33: config-i686-PAE
Source34: config-xen-x86

Source40: config-x86_64-generic
Source41: config-xen-x86_64

Source50: config-powerpc-generic
Source51: config-powerpc32-generic
Source52: config-powerpc32-smp
Source53: config-powerpc64
Source54: config-powerpc64-kdump

Source60: config-ia64-generic
Source61: config-ia64
Source62: config-xen-ia64

Source70: config-s390x

Source90: config-sparc64-generic
Source91: config-sparc64
Source92: config-sparc64-smp

# Here should be only the patches up to the upstream canonical Linus tree.

# For a stable release kernel
%if 0%{?stable_update}
Patch00: patch-2.6.%{base_sublevel}.%{stable_update}.bz2

# non-released_kernel case
# These are automagically defined by the rcrev and gitrev values set up
# near the top of this spec file.
%else
%if 0%{?rcrev}
Patch00: patch-2.6.%{upstream_sublevel}-rc%{rcrev}.bz2
%if 0%{?gitrev}
Patch01: patch-2.6.%{upstream_sublevel}-rc%{rcrev}-git%{gitrev}.bz2
%endif
%else
# pre-{base_sublevel+1}-rc1 case
%if 0%{?gitrev}
Patch00: patch-2.6.%{base_sublevel}-git%{gitrev}.bz2
%endif
%endif
%endif

%if %{using_upstream_branch}
### BRANCH PATCH ###
%endif

# stable release candidate
# Patch03: patch-2.6.24.1-rc1.bz2

# we always need nonintconfig, even for -vanilla kernels
Patch06: linux-2.6-build-nonintconfig.patch

# we also need compile fixes for -vanilla
Patch07: linux-2.6-compile-fixes.patch
Patch08: linux-2.6-compile-fix-gcc-43.patch

%if !%{nopatches}

Patch10: linux-2.6-hotfixes.patch

Patch21: linux-2.6-utrace.patch

Patch41: linux-2.6-sysrq-c.patch
Patch42: linux-2.6-x86-tune-generic.patch
Patch75: linux-2.6-x86-debug-boot.patch
Patch80: linux-2.6-smp-boot-delay.patch

Patch123: linux-2.6-ppc-rtc.patch
Patch140: linux-2.6-ps3-ehci-iso.patch
Patch141: linux-2.6-ps3-storage-alias.patch
Patch142: linux-2.6-ps3-legacy-bootloader-hack.patch
Patch143: linux-2.6-g5-therm-shutdown.patch
Patch144: linux-2.6-vio-modalias.patch
Patch145: linux-2.6-windfarm-pm121.patch
Patch146: linux-2.6-windfarm-pm121-fix.patch
Patch147: linux-2.6-imac-transparent-bridge.patch
Patch148: linux-2.6-powerpc-zImage-32MiB.patch
Patch149: linux-2.6-efika-not-chrp.patch

Patch160: linux-2.6-execshield.patch
Patch250: linux-2.6-debug-sizeof-structs.patch
Patch260: linux-2.6-debug-nmi-timeout.patch
Patch270: linux-2.6-debug-taint-vm.patch
Patch280: linux-2.6-debug-spinlock-taint.patch
Patch330: linux-2.6-debug-no-quiet.patch
Patch340: linux-2.6-debug-vm-would-have-oomkilled.patch
Patch350: linux-2.6-devmem.patch
Patch370: linux-2.6-crash-driver.patch
Patch400: linux-2.6-scsi-cpqarray-set-master.patch
Patch402: linux-2.6-scsi-mpt-vmware-fix.patch
Patch410: linux-2.6-alsa-kill-annoying-messages.patch
Patch420: linux-2.6-squashfs.patch
Patch430: linux-2.6-net-silence-noisy-printks.patch
Patch450: linux-2.6-input-kill-stupid-messages.patch
Patch460: linux-2.6-serial-460800.patch
Patch510: linux-2.6-silence-noise.patch
Patch570: linux-2.6-selinux-mprotect-checks.patch
Patch580: linux-2.6-sparc-selinux-mprotect-checks.patch
Patch610: linux-2.6-defaults-fat-utf8.patch
Patch670: linux-2.6-ata-quirk.patch

Patch680: linux-2.6-wireless.patch
Patch681: linux-2.6-wireless-pending.patch
Patch682: linux-2.6-rt2x00-configure_filter.patch
Patch690: linux-2.6-at76.patch

Patch700: linux-2.6-nfs-client-mounts-hang.patch

Patch1101: linux-2.6-default-mmf_dump_elf_headers.patch
Patch1400: linux-2.6-smarter-relatime.patch
Patch1515: linux-2.6-lirc.patch

# nouveau + drm fixes
Patch1801: linux-2.6-drm-git-mm.patch
Patch1803: nouveau-drm.patch
Patch1804: nouveau-drm-update.patch
Patch1806: linux-2.6-drm-i915-modeset.patch
Patch1807: linux-2.6-drm-radeon-fix-oops.patch
Patch1808: linux-2.6-drm-radeon-fix-oops2.patch

# kludge to make ich9 e1000 work
Patch2000: linux-2.6-e1000-ich9.patch

# Make Eee disk faster.
Patch2010: linux-2.6-sata-eeepc-faster.patch

# atl2 network driver
Patch2020: linux-2.6-netdev-atl2.patch

# ext4 patches
Patch2100: linux-2.6-ext4-stable-queue.patch

# linux1394 git patches
Patch2200: linux-2.6-firewire-git-update.patch
Patch2201: linux-2.6-firewire-git-pending.patch

# make USB EHCI driver respect "nousb" parameter
Patch2300: linux-2.6-usb-ehci-hcd-respect-nousb.patch
# Fix HID usage descriptor on MS wireless desktop receiver
Patch2301: linux-2.6-ms-wireless-receiver.patch

# acpi hotkey driver for asus eeepc
Patch2350: linux-2.6-acpi-eeepc-hotkey.patch

# usb video
Patch2400: linux-2.6-uvcvideo.patch

Patch2501: linux-2.6-ppc-use-libgcc.patch

# get rid of imacfb and make efifb work everywhere it was used
Patch2600: linux-2.6-merge-efifb-imacfb.patch

# kernel-xen patches start
Patch5000: linux-2.6-xen-0001-squashfs-Fix-build-without-CONFIG_SMP.patch
Patch5001: linux-2.6-xen-0002-xen-execshield-Add-xen-specific-load_user_cs_desc.patch
Patch5002: linux-2.6-xen-0003-xen-execshield-fix-endless-GPF-fault-loop.patch
Patch5003: linux-2.6-xen-0004-xen-Make-xen-blkfront-write-its-protocol-ABI-to-xen.patch
Patch5004: linux-2.6-xen-0005-xen-pvfb-Para-virtual-framebuffer-keyboard-and-poi.patch
Patch5005: linux-2.6-xen-0006-xen-Enable-Xen-console-by-default-in-domU.patch
Patch5006: linux-2.6-xen-0007-xen-Module-autoprobing-support-for-frontend-drivers.patch
Patch5007: linux-2.6-xen-0008-xen-Add-compatibility-aliases-for-frontend-drivers.patch
Patch5008: linux-2.6-xen-0009-xen-blkfront-Delay-wait-for-block-devices-until-aft.patch
Patch5009: linux-2.6-xen-0010-xen-Add-a-vmlinuz-target.patch
Patch5010: linux-2.6-xen-0011-xen-Add-empty-xenctrl-module.patch
Patch5011: linux-2.6-xen-0012-xen-Add-proc-xen-capabilities.patch
Patch5012: linux-2.6-xen-0013-xen-Add-proc-xen-privcmd.patch
Patch5013: linux-2.6-xen-0014-xen-Add-proc-xen-xenbus.patch
Patch5014: linux-2.6-xen-0015-xen-Add-Xen-s-sys-hypervisor-interface.patch
Patch5015: linux-2.6-xen-0016-xen-x86_64-Add-64-bit-version-of-privcmd_hypercall.patch
Patch5016: linux-2.6-xen-0017-xen-x86_64-Only-define-load_user_cs_desc-on-32-bi.patch
Patch5017: linux-2.6-xen-0018-xen-expose-set_pte_vaddr-and-make-xen-use-it.patch
Patch5018: linux-2.6-xen-0019-xen-dom0-Add-set_fixmap-pv_mmu_ops.patch
Patch5019: linux-2.6-xen-0020-x86_64-Expose-set_pte_vaddr.patch
Patch5020: linux-2.6-xen-0021-x86_64-Split-set_pte_vaddr.patch
Patch5021: linux-2.6-xen-0022-x86_64-Add-clear_fixmap.patch
Patch5022: linux-2.6-xen-0023-xen-x86_64-Make-set_fixmap-a-paravirt-op-on-64-bi.patch
Patch5023: linux-2.6-xen-0024-xen-x86_64-Hack-to-set-vsyscall-pages-on-user-space.patch
Patch5024: linux-2.6-xen-0025-Handle-VSYSCALL_FIRST_PAGE-on-xen_set_pte.patch
Patch5025: linux-2.6-xen-0026-DMI-Define-dmi_scan_machine-as-no-op-if-CONFIG_DM.patch
Patch5026: linux-2.6-xen-0027-ACPI-thermal-Compile-without-CONFIG_DMI.patch
Patch5027: linux-2.6-xen-0028-xen-x86_64-Remove-the-640K-1M-hole-and-disable-DMI.patch
Patch5028: linux-2.6-xen-0029-xen-x86_64-Add-update_va_mapping-64-bit-code.patch
Patch5029: linux-2.6-xen-0030-x86_64-Add-sync_cmpxchg.patch
Patch5030: linux-2.6-xen-0031-xen-x86_64-Implement-HYPERVISOR-MULTI-_update_desc.patch
Patch5031: linux-2.6-xen-0032-xen-x86_64-Add-hacky-64-bit-x86_-read-write-_percpu.patch
Patch5032: linux-2.6-xen-0033-xen-x86_64-Use-x86_read_percpu-only-to-refer-to-a.patch
Patch5033: linux-2.6-xen-0034-Better-implementation-of-pte-functions.patch
Patch5034: linux-2.6-xen-0035-Add-FIX_PARAVIRT_BOOTAP-to-fixmap_64.h-too.patch
Patch5035: linux-2.6-xen-0036-Add-gate_offset-and-gate_segment-macros.patch
Patch5036: linux-2.6-xen-0037-xen_write_idt_entry-and-cvt_gate_to_trap.patch
Patch5037: linux-2.6-xen-0038-typedefs-for-pte_val-and-friends.patch
Patch5038: linux-2.6-xen-0039-x86_64-implementation-of-some-page.h-macros.patch
Patch5039: linux-2.6-xen-0040-Chainsaw-style-ifdefs.patch
Patch5040: linux-2.6-xen-0041-xen-Make-xen_pte_val-generic.patch
Patch5041: linux-2.6-xen-0042-More-chainsaw-ifdefs.patch
Patch5042: linux-2.6-xen-0043-Chainsaw-ifdefs-on-assembly-percpu-handling.patch
Patch5043: linux-2.6-xen-0044-x86_64-percpu-assembly-macros.patch
Patch5044: linux-2.6-xen-0045-Some-xen-asm.S-x86_64-code.patch
Patch5045: linux-2.6-xen-0046-Chainsaw-party-SPLITME.patch
Patch5046: linux-2.6-xen-0047-xen-asm.S-x86_64-notes.patch
Patch5047: linux-2.6-xen-0048-xen-x86_64-Make-hypercall-assembly-code-work.patch
Patch5048: linux-2.6-xen-0049-xen-x86_64-pda-initialization.patch
Patch5049: linux-2.6-xen-0050-Disable-discover_ebda-under-paravirt.patch
Patch5050: linux-2.6-xen-0051-Disable-early_printk-by-default.patch
Patch5051: linux-2.6-xen-0052-xen-Set-__HYPERVISOR_VIRT_START-for-x86_64.patch
Patch5052: linux-2.6-xen-0053-Set-__PAGE_OFFSET-as-required-by-Xen.patch
Patch5053: linux-2.6-xen-0054-DEBUG-Add-xprintk-to-log-directly-via-hypercall-fo.patch
Patch5054: linux-2.6-xen-0055-DEBUG-Add-xprintk-debugging-printk-prototype-to-hvc.patch
Patch5055: linux-2.6-xen-0056-Use-__pgd-on-mk_kernel_pgd.patch
Patch5056: linux-2.6-xen-0057-Include-user-page-tables-on-head_64.S.patch
Patch5057: linux-2.6-xen-0058-Avoid-using-mk_unsigned_long.patch
Patch5058: linux-2.6-xen-0059-Lots-of-unrelated-changes.patch
Patch5059: linux-2.6-xen-0060-Hack-disable-vsmp.patch
Patch5060: linux-2.6-xen-0061-Export-early_make_page_readonly.patch
Patch5061: linux-2.6-xen-0062-Disable-multicalls.c-too-verbose-debugging.patch
Patch5062: linux-2.6-xen-0063-Xen-64-bit-ready-MMU-operations.patch
Patch5063: linux-2.6-xen-0064-Some-xen-mmu-pv-ops-implemented.patch
Patch5064: linux-2.6-xen-0065-Trying-to-make-the-pagetable-initialization-code-wor.patch
Patch5065: linux-2.6-xen-0066-Xen-specific-find_early_table_space-FIXME.patch
Patch5066: linux-2.6-xen-0067-Xen-call-e820_print_map-when-setting-up-memory.patch
Patch5067: linux-2.6-xen-0068-Comment-debugging-msgs.patch
Patch5068: linux-2.6-xen-0069-Try-to-make-pagetables-read-only.patch
Patch5069: linux-2.6-xen-0070-Debug-dump-pgtables-on-make_page_readonly.patch
Patch5070: linux-2.6-xen-0071-Disable-apic-at-compile-time-FIXME.patch
Patch5071: linux-2.6-xen-0072-Parse-early-params-after-init_memory_mapping.patch
Patch5072: linux-2.6-xen-0073-xen-Move-addr_to_page-to-init.h.patch
Patch5073: linux-2.6-xen-0074-Make-xen_pxx_val-and-xen_make_pxx-handle-attr-bi.patch
Patch5074: linux-2.6-xen-0075-Pull-xen_finish_init_mappin-from-XS-upstream.patch
Patch5075: linux-2.6-xen-0076-Pull-spp_getpage-changes-from-XS-upstream-REVIEWM.patch
Patch5076: linux-2.6-xen-0077-Pull-xen_extend_init_mapping-from-XS-upstream-FIX.patch
Patch5077: linux-2.6-xen-0078-New-enum-fixed_addresses-values-REVIEWME.patch
Patch5078: linux-2.6-xen-0079-Reserve-bootmem-areas-used-by-Xen-FIXME.patch
Patch5079: linux-2.6-xen-0080-xen_convert_trap_info-use-sizeof-struct-gate_desc.patch
Patch5080: linux-2.6-xen-0081-Call-paravirt_pagetable_setup_-start-done-REVIEW.patch
Patch5081: linux-2.6-xen-0082-ifdef-CONFIG_X86_32-on-xen-enlighten.c-REVIEWME.patch
Patch5082: linux-2.6-xen-0083-Handle-Xen-exception-stack-it-is-different-from-bar.patch
Patch5083: linux-2.6-xen-0084-Implement-64-bit-version-of-HYPERVISOR_set_callbacks.patch
Patch5084: linux-2.6-xen-0085-Make-arch_vcpu_info-be-of-the-right-size-on-both-32.patch
Patch5085: linux-2.6-xen-0086-Implement-asm-xen_iret.patch
Patch5086: linux-2.6-xen-0087-xen-64-xen_iret-use-iretq-directly-if-returning-t.patch
Patch5087: linux-2.6-xen-0088-Implement-xen_irqenable_syscall_ret.patch
Patch5088: linux-2.6-xen-0089-DEBUG-xen_iret-always-return-through-the-hyperviso.patch
Patch5089: linux-2.6-xen-0090-Implement-some-xen-callbacks-on-xen-entry_64.S.patch
Patch5090: linux-2.6-xen-0091-Xen-specific-ifdef-hacks-on-kernel-entry_64.S-FIXM.patch
Patch5091: linux-2.6-xen-0092-Disable-syscall32-code-temporarily-FIXME.patch
Patch5092: linux-2.6-xen-0093-Use-__KERNEL_DS-as-SS-when-returning-to-a-kernel-thr.patch
Patch5093: linux-2.6-xen-0094-Use-apic_xen-on-genapic-by-default-FIXME.patch
Patch5094: linux-2.6-xen-0095-irq-vector-ifdef-chainsaw-FIXME.patch
Patch5095: linux-2.6-xen-0096-ifdef-chainsaw-on-syscall_init-FIXME.patch
Patch5096: linux-2.6-xen-0097-Pull-xen-genapic-implementation-from-upstream-Xen.patch
Patch5097: linux-2.6-xen-0098-Debugging-printk-s.patch
Patch5098: linux-2.6-xen-0099-Leave-lazy_cpu_mode-on-__switch_to.patch
Patch5099: linux-2.6-xen-0100-xen-64-Handle-fs-and-gs-on-xen_load_tls-properl.patch
Patch5100: linux-2.6-xen-0101-Disable-vcpu_info_placement-temporarily-FIXME.patch
Patch5101: linux-2.6-xen-0102-Fix-typo-on-ifdef-again.patch
Patch5102: linux-2.6-xen-0103-DEBUG-Don-t-try-to-actually-read-the-page-on-show_.patch
Patch5103: linux-2.6-xen-0104-Make-load_gs_index-a-paravirt-operation.patch
Patch5104: linux-2.6-xen-0105-xen-pgd_walk-use-limit-argument-instead-of-FIXADD.patch
Patch5105: linux-2.6-xen-0106-xen-pgd_walk-Eliminate-BUG_ON-limit-FIXADDR_TOP.patch
Patch5106: linux-2.6-xen-0107-xen-pgd_walk-accept-start-parameter.patch
Patch5107: linux-2.6-xen-0108-xen-64-reserve_bootmem-xen_start_info-area.patch
Patch5108: linux-2.6-xen-0109-pvops-64-call-paravirt_post_allocator_init-on-set.patch
Patch5109: linux-2.6-xen-0110-use-write_gdt_entry-on-vsyscall_set_cpu-CLEANME.patch
Patch5110: linux-2.6-xen-0111-xen-64-implement-xen_load_gs_index.patch
Patch5111: linux-2.6-xen-0112-include-asm-x86-pgalloc_64.h-pvops-hacks-SPLITME.patch
Patch5112: linux-2.6-xen-0113-Multi-pagetable-write_cr3-implementation-FIXME.patch
Patch5113: linux-2.6-xen-0114-Disable-the-weird-count-loop-on-kcons_write_dom0.patch
Patch5114: linux-2.6-xen-0115-Make-xen_start_info-read-only.patch
Patch5115: linux-2.6-xen-0116-Hack-to-implement-return-to-userspace-without-SWAPGS.patch
Patch5116: linux-2.6-xen-0117-Xen-SEGBASE_-defines.patch
Patch5117: linux-2.6-xen-0118-Xen-HYPERVISOR_set_segment_base-implementation.patch
Patch5118: linux-2.6-xen-0119-Change-signature-of-paravirt_alloc_-pt-pd-REVIEWME.patch
Patch5119: linux-2.6-xen-0120-Comment-e820_print_map-call-TEMPORARY.patch
Patch5120: linux-2.6-xen-0121-Xen-missing-includes.patch
Patch5121: linux-2.6-xen-0122-asm-x86-pgtable_64.h-include-linux-spinlock.h.patch
Patch5122: linux-2.6-xen-0123-asm-x86-pgtable.h-include-asm-page.h.patch
Patch5123: linux-2.6-xen-0124-fix-pxxval_t-usage-on-mm-init_64.c.patch
Patch5124: linux-2.6-xen-0125-Missing-Xen-include.patch
Patch5125: linux-2.6-xen-0126-un-static-ipi_to_irq.patch
Patch5126: linux-2.6-xen-0127-Don-t-use-_PAGE_GLOBAL-bit-under-Xen-FIXME.patch
Patch5127: linux-2.6-xen-0128-Trying-to-organize-the-xen-bootmem-allocation-mess.patch
Patch5128: linux-2.6-xen-0129-Xen-reserve_bootmem-xenstore-and-console-interfac.patch
Patch5129: linux-2.6-xen-0130-pvops-64-call-paravirt_activate_mm-on-activate_mm.patch
Patch5130: linux-2.6-xen-0131-Xen-64-bit-support-on-xen_pgd_pin.patch
Patch5131: linux-2.6-xen-0132-Xen-64-pin-user-PGD-on-activate_mm-and-dup_mmap.patch
Patch5132: linux-2.6-xen-0133-pgd_walk-changes-to-make-pgd-pinning-work-FIXME.patch
Patch5133: linux-2.6-xen-0134-Xen-Add-a-order-parameter-to-pgd_walk.patch
Patch5134: linux-2.6-xen-0135-Xen-64-Unpin-user-pagetable-on-xen_pgd_unpin.patch
Patch5135: linux-2.6-xen-0136-Use-un-pin_page-when-un-pinning-pgd.patch
Patch5136: linux-2.6-xen-0137-Allow-enabling-Xen-on-x86_64.patch
Patch5137: linux-2.6-xen-0138-Add-include-linux-spinlock_types.h-to-asm-x86-pgt.patch
Patch5138: linux-2.6-xen-0139-Restore-some-sanity-on-the-initial-pagetable-bootmem.patch
Patch5139: linux-2.6-xen-0140-Xen-Use-system_call_after_swapgs-as-the-syscall-c.patch
Patch5140: linux-2.6-xen-0141-Add-a-system_call_after_saveargs-label-to-entry_64.S.patch
Patch5141: linux-2.6-xen-0142-Create-xen-specific-syscall-entry.patch
Patch5142: linux-2.6-xen-0143-syscall-related-Xen-ifdefs-FIXME.patch
Patch5143: linux-2.6-xen-0144-Point-set_pte-to-xen_set_pte-since-the-beginning.patch
Patch5144: linux-2.6-xen-0145-DEBUG-slab-debugging.patch
Patch5145: linux-2.6-xen-0146-pvops-64-Include-rsi-on-the-register-clobber-list.patch
Patch5146: linux-2.6-xen-0147-Xen-64-quick-ugly-hack-to-fix-pgd_clear-pagetabl.patch
Patch5147: linux-2.6-xen-0148-Add-missing-acpi-include-to-xen-setup.c.patch
Patch5148: linux-2.6-xen-0149-Don-t-use-FIX_VDSO-on-64-bit.patch
Patch5149: linux-2.6-xen-0150-Mark-init-pages-read-write-again-on-free_init_pages.patch
Patch5150: linux-2.6-xen-0151-reserve_early-kernel-text-and-data-segments.patch
Patch5151: linux-2.6-xen-0152-Xen-Clear-__START_KERNEL_map-PTEs-on-free_init_page.patch
Patch5152: linux-2.6-xen-0153-Set-pvops-machine_ops-for-Xen-on-x86_64-also-MERGE.patch
# kernel-xen patches end

# Xen hypervisor patches (20000+)
Patch20000: xen-compile-fix.patch
Patch20001: xen-version-strings.patch

# Xen ld --build-id option
# (http://fedoraproject.org/wiki/Releases/FeatureBuildId)
Patch20004: xen-build-id.patch

# Include build-id notes on xen-syms
Patch20005: xen-syms-build-id.patch

%endif

BuildRoot: %{_tmppath}/%{mainpkgname}-%{KVERREL}-root

%description
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system: memory allocation, process allocation, device
input and output, etc.


%package -n %{mainpkgname}-doc
Summary: Various documentation bits found in the kernel source
Group: Documentation
%description -n %{mainpkgname}-doc
This package contains documentation files from the kernel
source. Various bits of information about the Linux kernel and the
device drivers shipped with it are documented in these files.

You'll want to install this package if you need a reference to the
options that can be passed to Linux kernel modules at load time.


%package -n %{mainpkgname}-headers
Summary: Header files for the Linux kernel for use by glibc
Group: Development/System
Obsoletes: glibc-kernheaders
Provides: glibc-kernheaders = 3.0-46
%description -n %{mainpkgname}-headers
Kernel-headers includes the C header files that specify the interface
between the Linux kernel and userspace libraries and programs.  The
header files define structures and constants that are needed for
building most standard programs and are also needed for rebuilding the
glibc package.

%package bootwrapper
Summary: Boot wrapper files for generating combined kernel + initrd images
Group: Development/System
%description bootwrapper
Kernel-bootwrapper contains the wrapper code which makes bootable "zImage"
files combining both kernel and initial ramdisk.

%package -n %{mainpkgname}-debuginfo-common
Summary: Kernel source files used by %{mainpkgname}-debuginfo packages
Group: Development/Debug
Provides: %{mainpkgname}-debuginfo-common-%{_target_cpu} = %{version}-%{release}
%description -n %{mainpkgname}-debuginfo-common
This package is required by %{mainpkgname}-debuginfo subpackages.
It provides the kernel source files common to all builds.


#
# This macro creates a kernel-<subpackage>-debuginfo package.
#	%%kernel_debuginfo_package <subpackage>
#
%define kernel_debuginfo_package() \
%package -n %{variantbase}-%{?1:%{1}-}debuginfo\
Summary: Debug information for package %{variantbase}%{?1:-%{1}}\
Group: Development/Debug\
Requires: %{mainpkgname}-debuginfo-common-%{_target_cpu} = %{version}-%{release}\
Provides: %{variantbase}%{?1:-%{1}}-debuginfo-%{_target_cpu} = %{version}-%{release}\
AutoReqProv: no\
%description -n %{variantbase}%{?1:-%{1}}-debuginfo\
This package provides debug information for package %{variantbase}%{?1:-%{1}}.\
This is required to use SystemTap with %{variantbase}%{?1:-%{1}}-%{KVERREL}.\
%{expand:%%global debuginfo_args %{?debuginfo_args} -p '/.*/%%{KVERREL}%{?1:\.%{1}}/.*|/.*%%{KVERREL}%{?1:\.%{1}}(\.debug)?' -o debuginfo%{?1}.list}\
%{nil}

#
# This macro creates a kernel-<subpackage>-devel package.
#	%%kernel_devel_package <subpackage> <pretty-name>
#
%define kernel_devel_package() \
%package -n %{variantbase}-%{?1:%{1}-}devel\
Summary: Development package for building kernel modules to match the %{?2:%{2} }kernel\
Group: System Environment/Kernel\
Provides: kernel%{?1:-%{1}}-devel-%{_target_cpu} = %{version}-%{release}\
Provides: kernel-devel-%{_target_cpu} = %{version}-%{release}%{?1:.%{1}}\
Provides: kernel-devel = %{version}-%{release}%{?1:.%{1}}\
Provides: kernel-devel-uname-r = %{KVERREL}%{?1:.%{1}}\
AutoReqProv: no\
Requires(pre): /usr/bin/find\
%description -n %{variantbase}%{?1:-%{1}}-devel\
This package provides kernel headers and makefiles sufficient to build modules\
against the %{?2:%{2} }kernel package.\
%{nil}

#
# This macro creates a kernel-<subpackage> and its -devel and -debuginfo too.
#	%%define variant_summary The Linux kernel compiled for <configuration>
#	%%kernel_variant_package [-n <pretty-name>] <subpackage>
#
%define kernel_variant_package(n:) \
%package -n %{variantbase}-%1\
Summary: %{variant_summary}\
Group: System Environment/Kernel\
%kernel_reqprovconf\
%{expand:%%kernel_devel_package %1 %{!?-n:%1}%{?-n:%{-n*}}}\
%{expand:%%kernel_debuginfo_package %1}\
%{nil}


# First the auxiliary packages of the main kernel package.
%kernel_devel_package
%kernel_debuginfo_package


# Now, each variant package.

%define variant_summary The Linux kernel compiled for SMP machines
%kernel_variant_package -n SMP smp
%description -n %{variantbase}-smp
This package includes a SMP version of the Linux kernel. It is
required only on machines with two or more CPUs as well as machines with
hyperthreading technology.

Install the kernel-smp package if your machine uses two or more CPUs.


%define variant_summary The Linux kernel compiled for PAE capable machines
%kernel_variant_package PAE
%description -n %{variantbase}-PAE
This package includes a version of the Linux kernel with support for up to
64GB of high memory. It requires a CPU with Physical Address Extensions (PAE).
The non-PAE kernel can only address up to 4GB of memory.
Install the kernel-PAE package if your machine has more than 4GB of memory.


%define variant_summary The Linux kernel compiled with extra debugging enabled for PAE capable machines
%kernel_variant_package PAEdebug
Obsoletes: %{variantbase}-PAEdebug
%description -n %{variantbase}-PAEdebug
This package includes a version of the Linux kernel with support for up to
64GB of high memory. It requires a CPU with Physical Address Extensions (PAE).
The non-PAE kernel can only address up to 4GB of memory.
Install the kernel-PAE package if your machine has more than 4GB of memory.

This variant of the kernel has numerous debugging options enabled.
It should only be installed when trying to gather additional information
on kernel bugs, as some of these options impact performance noticably.


%define variant_summary The Linux kernel compiled with extra debugging enabled
%kernel_variant_package debug
%description -n %{variantbase}-debug
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

This variant of the kernel has numerous debugging options enabled.
It should only be installed when trying to gather additional information
on kernel bugs, as some of these options impact performance noticably.


%define variant_summary The Linux kernel compiled for Xen VM operations
%kernel_variant_package -n Xen xen
%description -n %{variantbase}-xen
This package includes version of the Linux kernel which
runs in a Xen VM. It works for both privileged and unprivileged guests.


%define variant_summary A minimal Linux kernel compiled for crash dumps
%kernel_variant_package kdump
%description -n %{variantbase}-kdump
This package includes a kdump version of the Linux kernel. It is
required only on machines which will use the kexec-based kernel crash dump
mechanism.


%prep
# do a few sanity-checks for --with *only builds
%if !%{with_doc}
%if %{with_baseonly}
%if !%{with_up}
echo "Cannot build --with baseonly, up build is disabled"
exit 1
%endif
%endif

%if %{with_smponly}
%if !%{with_smp}
echo "Cannot build --with smponly, smp build is disabled"
exit 1
%endif
%endif

%if %{with_paeonly}
%if !%{with_pae}
echo "Cannot build --with paeonly, pae build is disabled"
exit 1
%endif
%endif

%if %{with_xenonly}
%if !%{with_xen}
echo "Cannot build --with xenonly, xen build is disabled"
exit 1
%endif
%endif
%endif

# If the package has a variantbase set, the up (no variant suffix) packages would
# be inconsistent (sometimes using %%{mainpkgname}, other using %%{variantbase})
#
# As we only use variantbase on the kernel-xen package (that has with_up
# disabled), it is better to not support it than making the spec file
# more complex by adding magic to allow generating separated %%package sessions
# if necessary (the up variant has no %%package session because it has
# no subpackage suffix, but it uses the %%post and %%files section generation
# macros).
%if "%{mainpkgname}"!="%{variantbase}" && %{with_up}
echo "Setting %%{variantbase}!=%%{mainpkgname} is not support when building up kernels"
exit 1
%endif

patch_command='patch -p1 -F1 -s'
ApplyPatch()
{
  local patch=$1
  shift
  if [ ! -f $RPM_SOURCE_DIR/$patch ]; then
    exit 1;
  fi
  case "$patch" in
  *.bz2) bunzip2 < "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
  *.gz) gunzip < "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
  *) $patch_command ${1+"$@"} < "$RPM_SOURCE_DIR/$patch" ;;
  esac
}

# First we unpack the kernel tarball.
# If this isn't the first make prep, we use links to the existing clean tarball
# which speeds things up quite a bit.

# Update to latest upstream.
%if 0%{?released_kernel}
%define vanillaversion 2.6.%{base_sublevel}
# released_kernel with stable_update available case
%if 0%{?stable_update}
%define vanillaversion 2.6.%{base_sublevel}.%{stable_update}
%endif
# non-released_kernel case
%else
%if 0%{?rcrev}
%define vanillaversion 2.6.%{upstream_sublevel}-rc%{rcrev}
%if 0%{?gitrev}
%define vanillaversion 2.6.%{upstream_sublevel}-rc%{rcrev}-git%{gitrev}
%endif
%else
# pre-{base_sublevel+1}-rc1 case
%if 0%{?gitrev}
%define vanillaversion 2.6.%{base_sublevel}-git%{gitrev}
%endif
%endif
%endif

if [ ! -d kernel-%{kversion}/vanilla-%{vanillaversion} ]; then
  # Ok, first time we do a make prep.
  rm -f pax_global_header
%setup -q -n kernel-%{kversion} -c
  mv linux-%{kversion} vanilla-%{vanillaversion}
  cd vanilla-%{vanillaversion}

# Update vanilla to the latest upstream.
# released_kernel with stable_update available case
%if 0%{?stable_update}
ApplyPatch patch-2.6.%{base_sublevel}.%{stable_update}.bz2
# non-released_kernel case
%else
%if 0%{?rcrev}
ApplyPatch patch-2.6.%{upstream_sublevel}-rc%{rcrev}.bz2
%if 0%{?gitrev}
ApplyPatch patch-2.6.%{upstream_sublevel}-rc%{rcrev}-git%{gitrev}.bz2
%endif
%else
# pre-{base_sublevel+1}-rc1 case
%if 0%{?gitrev}
ApplyPatch patch-2.6.%{base_sublevel}-git%{gitrev}.bz2
%endif
%endif
%endif

 cd ..

else
  # We already have a vanilla dir.
  cd kernel-%{kversion}
  if [ -d linux-%{kversion}.%{_target_cpu} ]; then
     # Just in case we ctrl-c'd a prep already
     rm -rf deleteme.%{_target_cpu}
     # Move away the stale away, and delete in background.
     mv linux-%{kversion}.%{_target_cpu} deleteme.%{_target_cpu}
     rm -rf deleteme.%{_target_cpu} &
  fi
fi

cp -rl vanilla-%{vanillaversion} linux-%{kversion}.%{_target_cpu}

cd linux-%{kversion}.%{_target_cpu}

%if %{using_upstream_branch}
### BRANCH APPLY ###
%endif

# Drop some necessary files from the source dir into the buildroot
cp $RPM_SOURCE_DIR/config-* .
cp %{SOURCE15} .

# Dynamically generate kernel .config files from config-* files
make -f %{SOURCE20} VERSION=%{version} configs

#if a rhel kernel, apply the rhel config options
%if 0%{?rhel}
  for i in %{all_arch_configs}
  do
    mv $i $i.tmp
    ./merge.pl config-rhel-generic $i.tmp > $i
    rm $i.tmp
  done
  for i in kernel-%{version}-{i586,i686,i686-PAE,x86_64}*.config
  do
    echo i is this file  $i
    mv $i $i.tmp
    ./merge.pl config-rhel-x86-generic $i.tmp > $i
    rm $i.tmp
  done
%endif

# stable release candidate
# ApplyPatch patch-2.6.24.1-rc1.bz2

# This patch adds a "make nonint_oldconfig" which is non-interactive and
# also gives a list of missing options at the end. Useful for automated
# builds (as used in the buildsystem).
ApplyPatch linux-2.6-build-nonintconfig.patch

#
# misc small stuff to make things compile
#
C=$(wc -l $RPM_SOURCE_DIR/linux-2.6-compile-fixes.patch | awk '{print $1}')
if [ "$C" -gt 10 ]; then
ApplyPatch linux-2.6-compile-fixes.patch
fi

# build with gcc43
ApplyPatch linux-2.6-compile-fix-gcc-43.patch

%if !%{nopatches}

ApplyPatch linux-2.6-hotfixes.patch

# Roland's utrace ptrace replacement.
%ifnarch ia64
ApplyPatch linux-2.6-utrace.patch
%endif

# enable sysrq-c on all kernels, not only kexec
ApplyPatch linux-2.6-sysrq-c.patch

# Architecture patches
# x86(-64)
# Compile 686 kernels tuned for Pentium4.
ApplyPatch linux-2.6-x86-tune-generic.patch
# Delay longer during boot on x86 while waiting for secondary processors
ApplyPatch linux-2.6-smp-boot-delay.patch

#
# PowerPC
#
###  UPSTREAM PATCHES FROM 2.6.25 (we think):
# RTC class driver for ppc_md rtc functions
ApplyPatch linux-2.6-ppc-rtc.patch
### NOT (YET) UPSTREAM:
# The EHCI ISO patch isn't yet upstream but is needed to fix reboot
ApplyPatch linux-2.6-ps3-ehci-iso.patch
# Fixes some wireless optical mice
ApplyPatch linux-2.6-ms-wireless-receiver.patch
# The storage alias patch is Fedora-local, and allows the old 'ps3_storage'
# module name to work on upgrades. Otherwise, I believe mkinitrd will fail
# to pull the module in,
ApplyPatch linux-2.6-ps3-storage-alias.patch
# Support booting from Sony's original released 2.6.16-based kboot
ApplyPatch linux-2.6-ps3-legacy-bootloader-hack.patch
# Alleviate G5 thermal shutdown problems
ApplyPatch linux-2.6-g5-therm-shutdown.patch
# Provide modalias in sysfs for vio devices
ApplyPatch linux-2.6-vio-modalias.patch
# Fan support on iMac G5 iSight
ApplyPatch linux-2.6-windfarm-pm121.patch
ApplyPatch linux-2.6-windfarm-pm121-fix.patch
# Work around PCIe bridge setup on iSight
ApplyPatch linux-2.6-imac-transparent-bridge.patch
# Link zImage at 32MiB (for POWER machines, Efika)
ApplyPatch linux-2.6-powerpc-zImage-32MiB.patch
# Don't show 'CHRP' in /proc/cpuinfo on Efika
ApplyPatch linux-2.6-efika-not-chrp.patch

#
# Exec shield
#
ApplyPatch linux-2.6-execshield.patch

#
# bugfixes to drivers and filesystems
#

# USB
ApplyPatch linux-2.6-usb-ehci-hcd-respect-nousb.patch

# ACPI
# eeepc hotkey support
ApplyPatch linux-2.6-acpi-eeepc-hotkey.patch

# Various low-impact patches to aid debugging.
ApplyPatch linux-2.6-debug-sizeof-structs.patch
ApplyPatch linux-2.6-debug-nmi-timeout.patch
ApplyPatch linux-2.6-debug-taint-vm.patch
ApplyPatch linux-2.6-debug-spinlock-taint.patch
%if !%{debugbuildsenabled}
ApplyPatch linux-2.6-debug-no-quiet.patch
%endif
ApplyPatch linux-2.6-debug-vm-would-have-oomkilled.patch

#
# Make /dev/mem a need-to-know function
#
ApplyPatch linux-2.6-devmem.patch

#
# /dev/crash driver for the crashdump analysis tool
#
ApplyPatch linux-2.6-crash-driver.patch

#
# SCSI Bits.
#
# fix cpqarray pci enable
ApplyPatch linux-2.6-scsi-cpqarray-set-master.patch
# fix vmware emulated scsi controller
#ApplyPatch linux-2.6-scsi-mpt-vmware-fix.patch

# ALSA
#
ApplyPatch linux-2.6-alsa-kill-annoying-messages.patch

# Filesystem patches.
# Squashfs
ApplyPatch linux-2.6-squashfs.patch

# Networking
# Disable easy to trigger printk's.
ApplyPatch linux-2.6-net-silence-noisy-printks.patch

# Misc fixes
# The input layer spews crap no-one cares about.
ApplyPatch linux-2.6-input-kill-stupid-messages.patch

# Allow to use 480600 baud on 16C950 UARTs
ApplyPatch linux-2.6-serial-460800.patch
# Silence some useless messages that still get printed with 'quiet'
ApplyPatch linux-2.6-silence-noise.patch

# Fix the SELinux mprotect checks on executable mappings
ApplyPatch linux-2.6-selinux-mprotect-checks.patch
# Fix SELinux for sparc
ApplyPatch linux-2.6-sparc-selinux-mprotect-checks.patch

# Changes to upstream defaults.
# Use UTF-8 by default on VFAT.
ApplyPatch linux-2.6-defaults-fat-utf8.patch

# ia64 ata quirk
ApplyPatch linux-2.6-ata-quirk.patch

# wireless patches headed for 2.6.25
#ApplyPatch linux-2.6-wireless.patch
# wireless patches headed for 2.6.26
ApplyPatch linux-2.6-wireless-pending.patch
# rt2x00 configure_filter fix to avoid endless loop on insert for USB devices
ApplyPatch linux-2.6-rt2x00-configure_filter.patch

# Add misc wireless bits from upstream wireless tree
ApplyPatch linux-2.6-at76.patch

# implement smarter atime updates support.
ApplyPatch linux-2.6-smarter-relatime.patch

# NFS Client mounts hang when exported directory do not exist
ApplyPatch linux-2.6-nfs-client-mounts-hang.patch

# build id related enhancements
ApplyPatch linux-2.6-default-mmf_dump_elf_headers.patch

# http://www.lirc.org/
ApplyPatch linux-2.6-lirc.patch

ApplyPatch linux-2.6-e1000-ich9.patch

ApplyPatch linux-2.6-sata-eeepc-faster.patch

ApplyPatch linux-2.6-netdev-atl2.patch

# Nouveau DRM + drm fixes
ApplyPatch linux-2.6-drm-git-mm.patch
ApplyPatch nouveau-drm.patch
ApplyPatch nouveau-drm-update.patch
ApplyPatch linux-2.6-drm-i915-modeset.patch
ApplyPatch linux-2.6-drm-radeon-fix-oops.patch
ApplyPatch linux-2.6-drm-radeon-fix-oops2.patch

# ext4dev stable patch queue, slated for 2.6.25
#ApplyPatch linux-2.6-ext4-stable-queue.patch

# linux1394 git patches
ApplyPatch linux-2.6-firewire-git-update.patch
C=$(wc -l $RPM_SOURCE_DIR/linux-2.6-firewire-git-pending.patch | awk '{print $1}')
if [ "$C" -gt 10 ]; then
ApplyPatch linux-2.6-firewire-git-pending.patch
fi

# usb video
ApplyPatch linux-2.6-uvcvideo.patch

ApplyPatch linux-2.6-ppc-use-libgcc.patch

# get rid of imacfb and make efifb work everywhere it was used
ApplyPatch linux-2.6-merge-efifb-imacfb.patch

# ---------- below all scheduled for 2.6.24 -----------------

# kernel-xen apply start
ApplyPatch linux-2.6-xen-0001-squashfs-Fix-build-without-CONFIG_SMP.patch
ApplyPatch linux-2.6-xen-0002-xen-execshield-Add-xen-specific-load_user_cs_desc.patch
ApplyPatch linux-2.6-xen-0003-xen-execshield-fix-endless-GPF-fault-loop.patch
ApplyPatch linux-2.6-xen-0004-xen-Make-xen-blkfront-write-its-protocol-ABI-to-xen.patch
ApplyPatch linux-2.6-xen-0005-xen-pvfb-Para-virtual-framebuffer-keyboard-and-poi.patch
ApplyPatch linux-2.6-xen-0006-xen-Enable-Xen-console-by-default-in-domU.patch
ApplyPatch linux-2.6-xen-0007-xen-Module-autoprobing-support-for-frontend-drivers.patch
ApplyPatch linux-2.6-xen-0008-xen-Add-compatibility-aliases-for-frontend-drivers.patch
ApplyPatch linux-2.6-xen-0009-xen-blkfront-Delay-wait-for-block-devices-until-aft.patch
ApplyPatch linux-2.6-xen-0010-xen-Add-a-vmlinuz-target.patch
ApplyPatch linux-2.6-xen-0011-xen-Add-empty-xenctrl-module.patch
ApplyPatch linux-2.6-xen-0012-xen-Add-proc-xen-capabilities.patch
ApplyPatch linux-2.6-xen-0013-xen-Add-proc-xen-privcmd.patch
ApplyPatch linux-2.6-xen-0014-xen-Add-proc-xen-xenbus.patch
ApplyPatch linux-2.6-xen-0015-xen-Add-Xen-s-sys-hypervisor-interface.patch
%ifarch x86_64
ApplyPatch linux-2.6-xen-0016-xen-x86_64-Add-64-bit-version-of-privcmd_hypercall.patch
ApplyPatch linux-2.6-xen-0017-xen-x86_64-Only-define-load_user_cs_desc-on-32-bi.patch
ApplyPatch linux-2.6-xen-0018-xen-expose-set_pte_vaddr-and-make-xen-use-it.patch
ApplyPatch linux-2.6-xen-0019-xen-dom0-Add-set_fixmap-pv_mmu_ops.patch
ApplyPatch linux-2.6-xen-0020-x86_64-Expose-set_pte_vaddr.patch
ApplyPatch linux-2.6-xen-0021-x86_64-Split-set_pte_vaddr.patch
ApplyPatch linux-2.6-xen-0022-x86_64-Add-clear_fixmap.patch
ApplyPatch linux-2.6-xen-0023-xen-x86_64-Make-set_fixmap-a-paravirt-op-on-64-bi.patch
ApplyPatch linux-2.6-xen-0024-xen-x86_64-Hack-to-set-vsyscall-pages-on-user-space.patch
ApplyPatch linux-2.6-xen-0025-Handle-VSYSCALL_FIRST_PAGE-on-xen_set_pte.patch
ApplyPatch linux-2.6-xen-0026-DMI-Define-dmi_scan_machine-as-no-op-if-CONFIG_DM.patch
ApplyPatch linux-2.6-xen-0027-ACPI-thermal-Compile-without-CONFIG_DMI.patch
ApplyPatch linux-2.6-xen-0028-xen-x86_64-Remove-the-640K-1M-hole-and-disable-DMI.patch
ApplyPatch linux-2.6-xen-0029-xen-x86_64-Add-update_va_mapping-64-bit-code.patch
ApplyPatch linux-2.6-xen-0030-x86_64-Add-sync_cmpxchg.patch
ApplyPatch linux-2.6-xen-0031-xen-x86_64-Implement-HYPERVISOR-MULTI-_update_desc.patch
ApplyPatch linux-2.6-xen-0032-xen-x86_64-Add-hacky-64-bit-x86_-read-write-_percpu.patch
ApplyPatch linux-2.6-xen-0033-xen-x86_64-Use-x86_read_percpu-only-to-refer-to-a.patch
ApplyPatch linux-2.6-xen-0034-Better-implementation-of-pte-functions.patch
ApplyPatch linux-2.6-xen-0035-Add-FIX_PARAVIRT_BOOTAP-to-fixmap_64.h-too.patch
ApplyPatch linux-2.6-xen-0036-Add-gate_offset-and-gate_segment-macros.patch
ApplyPatch linux-2.6-xen-0037-xen_write_idt_entry-and-cvt_gate_to_trap.patch
ApplyPatch linux-2.6-xen-0038-typedefs-for-pte_val-and-friends.patch
ApplyPatch linux-2.6-xen-0039-x86_64-implementation-of-some-page.h-macros.patch
ApplyPatch linux-2.6-xen-0040-Chainsaw-style-ifdefs.patch
ApplyPatch linux-2.6-xen-0041-xen-Make-xen_pte_val-generic.patch
ApplyPatch linux-2.6-xen-0042-More-chainsaw-ifdefs.patch
ApplyPatch linux-2.6-xen-0043-Chainsaw-ifdefs-on-assembly-percpu-handling.patch
ApplyPatch linux-2.6-xen-0044-x86_64-percpu-assembly-macros.patch
ApplyPatch linux-2.6-xen-0045-Some-xen-asm.S-x86_64-code.patch
ApplyPatch linux-2.6-xen-0046-Chainsaw-party-SPLITME.patch
ApplyPatch linux-2.6-xen-0047-xen-asm.S-x86_64-notes.patch
ApplyPatch linux-2.6-xen-0048-xen-x86_64-Make-hypercall-assembly-code-work.patch
ApplyPatch linux-2.6-xen-0049-xen-x86_64-pda-initialization.patch
ApplyPatch linux-2.6-xen-0050-Disable-discover_ebda-under-paravirt.patch
ApplyPatch linux-2.6-xen-0051-Disable-early_printk-by-default.patch
ApplyPatch linux-2.6-xen-0052-xen-Set-__HYPERVISOR_VIRT_START-for-x86_64.patch
ApplyPatch linux-2.6-xen-0053-Set-__PAGE_OFFSET-as-required-by-Xen.patch
ApplyPatch linux-2.6-xen-0054-DEBUG-Add-xprintk-to-log-directly-via-hypercall-fo.patch
ApplyPatch linux-2.6-xen-0055-DEBUG-Add-xprintk-debugging-printk-prototype-to-hvc.patch
ApplyPatch linux-2.6-xen-0056-Use-__pgd-on-mk_kernel_pgd.patch
ApplyPatch linux-2.6-xen-0057-Include-user-page-tables-on-head_64.S.patch
ApplyPatch linux-2.6-xen-0058-Avoid-using-mk_unsigned_long.patch
ApplyPatch linux-2.6-xen-0059-Lots-of-unrelated-changes.patch
ApplyPatch linux-2.6-xen-0060-Hack-disable-vsmp.patch
ApplyPatch linux-2.6-xen-0061-Export-early_make_page_readonly.patch
ApplyPatch linux-2.6-xen-0062-Disable-multicalls.c-too-verbose-debugging.patch
ApplyPatch linux-2.6-xen-0063-Xen-64-bit-ready-MMU-operations.patch
ApplyPatch linux-2.6-xen-0064-Some-xen-mmu-pv-ops-implemented.patch
ApplyPatch linux-2.6-xen-0065-Trying-to-make-the-pagetable-initialization-code-wor.patch
ApplyPatch linux-2.6-xen-0066-Xen-specific-find_early_table_space-FIXME.patch
ApplyPatch linux-2.6-xen-0067-Xen-call-e820_print_map-when-setting-up-memory.patch
ApplyPatch linux-2.6-xen-0068-Comment-debugging-msgs.patch
ApplyPatch linux-2.6-xen-0069-Try-to-make-pagetables-read-only.patch
ApplyPatch linux-2.6-xen-0070-Debug-dump-pgtables-on-make_page_readonly.patch
ApplyPatch linux-2.6-xen-0071-Disable-apic-at-compile-time-FIXME.patch
ApplyPatch linux-2.6-xen-0072-Parse-early-params-after-init_memory_mapping.patch
ApplyPatch linux-2.6-xen-0073-xen-Move-addr_to_page-to-init.h.patch
ApplyPatch linux-2.6-xen-0074-Make-xen_pxx_val-and-xen_make_pxx-handle-attr-bi.patch
ApplyPatch linux-2.6-xen-0075-Pull-xen_finish_init_mappin-from-XS-upstream.patch
ApplyPatch linux-2.6-xen-0076-Pull-spp_getpage-changes-from-XS-upstream-REVIEWM.patch
ApplyPatch linux-2.6-xen-0077-Pull-xen_extend_init_mapping-from-XS-upstream-FIX.patch
ApplyPatch linux-2.6-xen-0078-New-enum-fixed_addresses-values-REVIEWME.patch
ApplyPatch linux-2.6-xen-0079-Reserve-bootmem-areas-used-by-Xen-FIXME.patch
ApplyPatch linux-2.6-xen-0080-xen_convert_trap_info-use-sizeof-struct-gate_desc.patch
ApplyPatch linux-2.6-xen-0081-Call-paravirt_pagetable_setup_-start-done-REVIEW.patch
ApplyPatch linux-2.6-xen-0082-ifdef-CONFIG_X86_32-on-xen-enlighten.c-REVIEWME.patch
ApplyPatch linux-2.6-xen-0083-Handle-Xen-exception-stack-it-is-different-from-bar.patch
ApplyPatch linux-2.6-xen-0084-Implement-64-bit-version-of-HYPERVISOR_set_callbacks.patch
ApplyPatch linux-2.6-xen-0085-Make-arch_vcpu_info-be-of-the-right-size-on-both-32.patch
ApplyPatch linux-2.6-xen-0086-Implement-asm-xen_iret.patch
ApplyPatch linux-2.6-xen-0087-xen-64-xen_iret-use-iretq-directly-if-returning-t.patch
ApplyPatch linux-2.6-xen-0088-Implement-xen_irqenable_syscall_ret.patch
ApplyPatch linux-2.6-xen-0089-DEBUG-xen_iret-always-return-through-the-hyperviso.patch
ApplyPatch linux-2.6-xen-0090-Implement-some-xen-callbacks-on-xen-entry_64.S.patch
ApplyPatch linux-2.6-xen-0091-Xen-specific-ifdef-hacks-on-kernel-entry_64.S-FIXM.patch
ApplyPatch linux-2.6-xen-0092-Disable-syscall32-code-temporarily-FIXME.patch
ApplyPatch linux-2.6-xen-0093-Use-__KERNEL_DS-as-SS-when-returning-to-a-kernel-thr.patch
ApplyPatch linux-2.6-xen-0094-Use-apic_xen-on-genapic-by-default-FIXME.patch
ApplyPatch linux-2.6-xen-0095-irq-vector-ifdef-chainsaw-FIXME.patch
ApplyPatch linux-2.6-xen-0096-ifdef-chainsaw-on-syscall_init-FIXME.patch
ApplyPatch linux-2.6-xen-0097-Pull-xen-genapic-implementation-from-upstream-Xen.patch
ApplyPatch linux-2.6-xen-0098-Debugging-printk-s.patch
ApplyPatch linux-2.6-xen-0099-Leave-lazy_cpu_mode-on-__switch_to.patch
ApplyPatch linux-2.6-xen-0100-xen-64-Handle-fs-and-gs-on-xen_load_tls-properl.patch
ApplyPatch linux-2.6-xen-0101-Disable-vcpu_info_placement-temporarily-FIXME.patch
ApplyPatch linux-2.6-xen-0102-Fix-typo-on-ifdef-again.patch
ApplyPatch linux-2.6-xen-0103-DEBUG-Don-t-try-to-actually-read-the-page-on-show_.patch
ApplyPatch linux-2.6-xen-0104-Make-load_gs_index-a-paravirt-operation.patch
ApplyPatch linux-2.6-xen-0105-xen-pgd_walk-use-limit-argument-instead-of-FIXADD.patch
ApplyPatch linux-2.6-xen-0106-xen-pgd_walk-Eliminate-BUG_ON-limit-FIXADDR_TOP.patch
ApplyPatch linux-2.6-xen-0107-xen-pgd_walk-accept-start-parameter.patch
ApplyPatch linux-2.6-xen-0108-xen-64-reserve_bootmem-xen_start_info-area.patch
ApplyPatch linux-2.6-xen-0109-pvops-64-call-paravirt_post_allocator_init-on-set.patch
ApplyPatch linux-2.6-xen-0110-use-write_gdt_entry-on-vsyscall_set_cpu-CLEANME.patch
ApplyPatch linux-2.6-xen-0111-xen-64-implement-xen_load_gs_index.patch
ApplyPatch linux-2.6-xen-0112-include-asm-x86-pgalloc_64.h-pvops-hacks-SPLITME.patch
ApplyPatch linux-2.6-xen-0113-Multi-pagetable-write_cr3-implementation-FIXME.patch
ApplyPatch linux-2.6-xen-0114-Disable-the-weird-count-loop-on-kcons_write_dom0.patch
ApplyPatch linux-2.6-xen-0115-Make-xen_start_info-read-only.patch
ApplyPatch linux-2.6-xen-0116-Hack-to-implement-return-to-userspace-without-SWAPGS.patch
ApplyPatch linux-2.6-xen-0117-Xen-SEGBASE_-defines.patch
ApplyPatch linux-2.6-xen-0118-Xen-HYPERVISOR_set_segment_base-implementation.patch
ApplyPatch linux-2.6-xen-0119-Change-signature-of-paravirt_alloc_-pt-pd-REVIEWME.patch
ApplyPatch linux-2.6-xen-0120-Comment-e820_print_map-call-TEMPORARY.patch
ApplyPatch linux-2.6-xen-0121-Xen-missing-includes.patch
ApplyPatch linux-2.6-xen-0122-asm-x86-pgtable_64.h-include-linux-spinlock.h.patch
ApplyPatch linux-2.6-xen-0123-asm-x86-pgtable.h-include-asm-page.h.patch
ApplyPatch linux-2.6-xen-0124-fix-pxxval_t-usage-on-mm-init_64.c.patch
ApplyPatch linux-2.6-xen-0125-Missing-Xen-include.patch
ApplyPatch linux-2.6-xen-0126-un-static-ipi_to_irq.patch
ApplyPatch linux-2.6-xen-0127-Don-t-use-_PAGE_GLOBAL-bit-under-Xen-FIXME.patch
ApplyPatch linux-2.6-xen-0128-Trying-to-organize-the-xen-bootmem-allocation-mess.patch
ApplyPatch linux-2.6-xen-0129-Xen-reserve_bootmem-xenstore-and-console-interfac.patch
ApplyPatch linux-2.6-xen-0130-pvops-64-call-paravirt_activate_mm-on-activate_mm.patch
ApplyPatch linux-2.6-xen-0131-Xen-64-bit-support-on-xen_pgd_pin.patch
ApplyPatch linux-2.6-xen-0132-Xen-64-pin-user-PGD-on-activate_mm-and-dup_mmap.patch
ApplyPatch linux-2.6-xen-0133-pgd_walk-changes-to-make-pgd-pinning-work-FIXME.patch
ApplyPatch linux-2.6-xen-0134-Xen-Add-a-order-parameter-to-pgd_walk.patch
ApplyPatch linux-2.6-xen-0135-Xen-64-Unpin-user-pagetable-on-xen_pgd_unpin.patch
ApplyPatch linux-2.6-xen-0136-Use-un-pin_page-when-un-pinning-pgd.patch
ApplyPatch linux-2.6-xen-0137-Allow-enabling-Xen-on-x86_64.patch
ApplyPatch linux-2.6-xen-0138-Add-include-linux-spinlock_types.h-to-asm-x86-pgt.patch
ApplyPatch linux-2.6-xen-0139-Restore-some-sanity-on-the-initial-pagetable-bootmem.patch
ApplyPatch linux-2.6-xen-0140-Xen-Use-system_call_after_swapgs-as-the-syscall-c.patch
ApplyPatch linux-2.6-xen-0141-Add-a-system_call_after_saveargs-label-to-entry_64.S.patch
ApplyPatch linux-2.6-xen-0142-Create-xen-specific-syscall-entry.patch
ApplyPatch linux-2.6-xen-0143-syscall-related-Xen-ifdefs-FIXME.patch
ApplyPatch linux-2.6-xen-0144-Point-set_pte-to-xen_set_pte-since-the-beginning.patch
ApplyPatch linux-2.6-xen-0145-DEBUG-slab-debugging.patch
ApplyPatch linux-2.6-xen-0146-pvops-64-Include-rsi-on-the-register-clobber-list.patch
ApplyPatch linux-2.6-xen-0147-Xen-64-quick-ugly-hack-to-fix-pgd_clear-pagetabl.patch
ApplyPatch linux-2.6-xen-0148-Add-missing-acpi-include-to-xen-setup.c.patch
ApplyPatch linux-2.6-xen-0149-Don-t-use-FIX_VDSO-on-64-bit.patch
ApplyPatch linux-2.6-xen-0150-Mark-init-pages-read-write-again-on-free_init_pages.patch
ApplyPatch linux-2.6-xen-0151-reserve_early-kernel-text-and-data-segments.patch
ApplyPatch linux-2.6-xen-0152-Xen-Clear-__START_KERNEL_map-PTEs-on-free_init_page.patch
ApplyPatch linux-2.6-xen-0153-Set-pvops-machine_ops-for-Xen-on-x86_64-also-MERGE.patch
%endif
# kernel-xen apply end

# END OF PATCH APPLICATIONS

%endif

# Any further pre-build tree manipulations happen here.

chmod +x scripts/checkpatch.pl

cp %{SOURCE10} Documentation/

# only deal with configs if we are going to build for the arch
%ifnarch %nobuildarches

mkdir configs

# Remove configs not for the buildarch
for cfg in kernel-%{version}-*.config; do
  if [ `echo %{all_arch_configs} | grep -c $cfg` -eq 0 ]; then
    rm -f $cfg
  fi
done

%if !%{debugbuildsenabled}
rm -f kernel-%{version}-*debug.config
%endif

# now run oldconfig over all the config files
for i in *.config
do
  mv $i .config
  Arch=`head -1 .config | cut -b 3-`
  make ARCH=$Arch %{oldconfig_target} > /dev/null
  echo "# $Arch" > configs/$i
  cat .config >> configs/$i
done
# end of kernel config
%endif

# get rid of unwanted files resulting from patch fuzz
find . \( -name "*.orig" -o -name "*~" \) -exec rm -f {} \; >/dev/null

cd ..

# Unpack the Xen tarball.
%if %{includexen}
cp %{SOURCE2} .
if [ -d %{xen_hv_dirname} ]; then
  rm -rf %{xen_hv_dirname}
fi
%setup -D -T -q -n kernel-%{kversion} -a1
cd %{xen_hv_dirname}/
# Any necessary hypervisor patches go here
ApplyPatch xen-compile-fix.patch
ApplyPatch xen-version-strings.patch
ApplyPatch xen-build-id.patch
ApplyPatch xen-syms-build-id.patch
%endif


###
### build
###
%build

%if %{with_sparse}
%define sparse_mflags	C=1
%endif

%if %{fancy_debuginfo}
# This override tweaks the kernel makefiles so that we run debugedit on an
# object before embedding it.  When we later run find-debuginfo.sh, it will
# run debugedit again.  The edits it does change the build ID bits embedded
# in the stripped object, but repeating debugedit is a no-op.  We do it
# beforehand to get the proper final build ID bits into the embedded image.
# This affects the vDSO images in vmlinux, and the vmlinux image in bzImage.
idhack='cmd_objcopy=$(if $(filter -S,$(OBJCOPYFLAGS)),'\
'sh -xc "/usr/lib/rpm/debugedit -b $$RPM_BUILD_DIR -d /usr/src/debug -i $<";)'\
'$(OBJCOPY) $(OBJCOPYFLAGS) $(OBJCOPYFLAGS_$(@F)) $< $@'
%endif

cp_vmlinux()
{
  eu-strip --remove-comment -o "$2" "$1"
}

BuildKernel() {
    MakeTarget=$1
    KernelImage=$2
    Flavour=$3
    InstallName=${4:-vmlinuz}

    # Pick the right config file for the kernel we're building
    Config=kernel-%{version}-%{_target_cpu}${Flavour:+-${Flavour}}.config
    DevelDir=/usr/src/kernels/%{KVERREL}${Flavour:+.${Flavour}}

    # When the bootable image is just the ELF kernel, strip it.
    # We already copy the unstripped file into the debuginfo package.
    if [ "$KernelImage" = vmlinux ]; then
      CopyKernel=cp_vmlinux
    else
      CopyKernel=cp
    fi

    KernelVer=%{version}-%{release}.%{_target_cpu}${Flavour:+.${Flavour}}
    echo BUILDING A KERNEL FOR ${Flavour} %{_target_cpu}...

    # make sure EXTRAVERSION says what we want it to say
    perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = %{?stablerev}-%{release}.%{_target_cpu}${Flavour:+.${Flavour}}/" Makefile

    # if pre-rc1 devel kernel, must fix up SUBLEVEL for our versioning scheme
    %if !0%{?rcrev}
    %if 0%{?gitrev}
    perl -p -i -e 's/^SUBLEVEL.*/SUBLEVEL = %{upstream_sublevel}/' Makefile
    %endif
    %endif

    # and now to start the build process

    make -s mrproper
    cp configs/$Config .config

    Arch=`head -1 .config | cut -b 3-`
    echo USING ARCH=$Arch

    make -s ARCH=$Arch %{oldconfig_target} > /dev/null
    make -s ARCH=$Arch %{?_smp_mflags} $MakeTarget %{?sparse_mflags} \
    	 ${idhack+"$idhack"}
    make -s ARCH=$Arch %{?_smp_mflags} modules %{?sparse_mflags} || exit 1

    # Start installing the results
%if %{with_debuginfo}
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/boot
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/%{image_install_path}
%endif
    mkdir -p $RPM_BUILD_ROOT/%{image_install_path}
    install -m 644 .config $RPM_BUILD_ROOT/boot/config-$KernelVer
    install -m 644 System.map $RPM_BUILD_ROOT/boot/System.map-$KernelVer
    touch $RPM_BUILD_ROOT/boot/initrd-$KernelVer.img
    if [ -f arch/$Arch/boot/zImage.stub ]; then
      cp arch/$Arch/boot/zImage.stub $RPM_BUILD_ROOT/%{image_install_path}/zImage.stub-$KernelVer || :
    fi
    $CopyKernel $KernelImage \
    		$RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer
    chmod 755 $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer

    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer
    make -s ARCH=$Arch INSTALL_MOD_PATH=$RPM_BUILD_ROOT modules_install KERNELRELEASE=$KernelVer
%ifarch %{vdso_arches}
    make -s ARCH=$Arch INSTALL_MOD_PATH=$RPM_BUILD_ROOT vdso_install KERNELRELEASE=$KernelVer
%endif

    # And save the headers/makefiles etc for building modules against
    #
    # This all looks scary, but the end result is supposed to be:
    # * all arch relevant include/ files
    # * all Makefile/Kconfig files
    # * all script/ files

    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/source
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    (cd $RPM_BUILD_ROOT/lib/modules/$KernelVer ; ln -s build source)
    # dirs for additional modules per module-init-tools, kbuild/modules.txt
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/extra
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/updates
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/weak-updates
    # first copy everything
    cp --parents `find  -type f -name "Makefile*" -o -name "Kconfig*"` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp Module.symvers $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp System.map $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    if [ -s Module.markers ]; then
      cp Module.markers $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    fi
    # then drop all but the needed Makefiles/Kconfig files
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Documentation
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cp .config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    if [ -d arch/%{_arch}/scripts ]; then
      cp -a arch/%{_arch}/scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch} || :
    fi
    if [ -f arch/%{_arch}/*lds ]; then
      cp -a arch/%{_arch}/*lds $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch}/ || :
    fi
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*.o
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*/*.o
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cd include
    cp -a acpi config keys linux math-emu media mtd net pcmcia rdma rxrpc scsi sound video asm asm-generic $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cp -a `readlink asm` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    # While arch/powerpc/include/asm is still a symlink to the old
    # include/asm-ppc{64,} directory, include that in kernel-devel too.
    if [ "$Arch" = "powerpc" -a -r ../arch/powerpc/include/asm ]; then
      cp -a `readlink ../arch/powerpc/include/asm` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
      mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/$Arch/include
      pushd $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/$Arch/include
      ln -sf ../../../include/asm-ppc* asm
      popd
    fi
%if %{includexen}
    cp -a xen $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
%endif

    # Make sure the Makefile and version.h have a matching timestamp so that
    # external modules can be built
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Makefile $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/linux/version.h
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/.config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/linux/autoconf.h
    # Copy .config to include/config/auto.conf so "make prepare" is unnecessary.
    cp $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/.config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/config/auto.conf
    cd ..

    #
    # save the vmlinux file for kernel debugging into the kernel-debuginfo rpm
    #
%if %{with_debuginfo}
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer
    cp vmlinux $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer
%endif

    find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.ko" -type f >modnames

    # mark modules executable so that strip-to-file can strip them
    xargs --no-run-if-empty chmod u+x < modnames

    # Generate a list of modules for block and networking.

    fgrep /drivers/ modnames | xargs --no-run-if-empty nm -upA |
    sed -n 's,^.*/\([^/]*\.ko\):  *U \(.*\)$,\1 \2,p' > drivers.undef

    collect_modules_list()
    {
      sed -r -n -e "s/^([^ ]+) \\.?($2)\$/\\1/p" drivers.undef |
      LC_ALL=C sort -u > $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.$1
    }

    collect_modules_list networking \
    			 'register_netdev|ieee80211_register_hw|usbnet_probe'
    collect_modules_list block \
    			 'ata_scsi_ioctl|scsi_add_host|blk_init_queue|register_mtd_blktrans'

    # detect missing or incorrect license tags
    rm -f modinfo
    while read i
    do
      echo -n "${i#$RPM_BUILD_ROOT/lib/modules/$KernelVer/} " >> modinfo
      /sbin/modinfo -l $i >> modinfo
    done < modnames

    egrep -v \
    	  'GPL( v2)?$|Dual BSD/GPL$|Dual MPL/GPL$|GPL and additional rights$' \
	  modinfo && exit 1

    rm -f modinfo modnames

    # remove files that will be auto generated by depmod at rpm -i time
    for i in alias ccwmap dep ieee1394map inputmap isapnpmap ofmap pcimap seriomap symbols usbmap
    do
      rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.$i
    done

    # Move the devel headers out of the root file system
    mkdir -p $RPM_BUILD_ROOT/usr/src/kernels
    mv $RPM_BUILD_ROOT/lib/modules/$KernelVer/build $RPM_BUILD_ROOT/$DevelDir
    ln -sf ../../..$DevelDir $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
}

###
# DO it...
###

# prepare directories
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/boot

%if %{includexen}
%if %{with_xen}
  cd %{xen_hv_dirname}/xen/
  mkdir -p $RPM_BUILD_ROOT/%{image_install_path} $RPM_BUILD_ROOT/boot
  make %{?_smp_mflags} %{xen_flags}
  install -m 644 xen.gz $RPM_BUILD_ROOT/%{image_install_path}/xen.gz-%{KVERREL}.xen
  install -m 755 xen-syms $RPM_BUILD_ROOT/boot/xen-syms-%{KVERREL}.xen
  cd ../..
%endif
%endif

cd linux-%{kversion}.%{_target_cpu}

%if %{with_debug}
BuildKernel %make_target %kernel_image debug
%if %{with_pae}
BuildKernel %make_target %kernel_image PAEdebug
%endif
%endif

%if %{with_pae}
BuildKernel %make_target %kernel_image PAE
%endif

%if %{with_up}
BuildKernel %make_target %kernel_image
%endif

%if %{with_smp}
BuildKernel %make_target %kernel_image smp
%endif

%if %{includexen}
%if %{with_xen}
BuildKernel %xen_target %xen_image xen
%endif
%endif

%if %{with_kdump}
BuildKernel vmlinux vmlinux kdump vmlinux
%endif

###
### Special hacks for debuginfo subpackages.
###

# This macro is used by %%install, so we must redefine it before that.
%define debug_package %{nil}

%if %{fancy_debuginfo}
%define __debug_install_post \
  /usr/lib/rpm/find-debuginfo.sh %{debuginfo_args} %{_builddir}/%{?buildsubdir}\
%{nil}
%endif

%if %{with_debuginfo}
%ifnarch noarch
%global __debug_package 1
%files -f debugfiles.list -n %{mainpkgname}-debuginfo-common
%defattr(-,root,root)
%endif
%endif

###
### install
###

%install

cd linux-%{kversion}.%{_target_cpu}

%if %{includexen}
%if %{with_xen}
mkdir -p $RPM_BUILD_ROOT/etc/ld.so.conf.d
rm -f $RPM_BUILD_ROOT/etc/ld.so.conf.d/kernelcap-%{KVERREL}.xen.conf
cat > $RPM_BUILD_ROOT/etc/ld.so.conf.d/kernelcap-%{KVERREL}.xen.conf <<\EOF
# This directive teaches ldconfig to search in nosegneg subdirectories
# and cache the DSOs there with extra bit 0 set in their hwcap match
# fields.  In Xen guest kernels, the vDSO tells the dynamic linker to
# search in nosegneg subdirectories and to match this extra hwcap bit
# in the ld.so.cache file.
hwcap 0 nosegneg
EOF
chmod 444 $RPM_BUILD_ROOT/etc/ld.so.conf.d/kernelcap-%{KVERREL}.xen.conf
%endif
%endif

%if %{with_doc}
mkdir -p $RPM_BUILD_ROOT/usr/share/doc/kernel-doc-%{kversion}/Documentation

# sometimes non-world-readable files sneak into the kernel source tree
chmod -R a+r *
# copy the source over
tar cf - Documentation | tar xf - -C $RPM_BUILD_ROOT/usr/share/doc/kernel-doc-%{kversion}

# Make man pages for the kernel API.
make mandocs
mkdir -p $RPM_BUILD_ROOT/usr/share/man/man9
mv Documentation/DocBook/man/*.9.gz $RPM_BUILD_ROOT/usr/share/man/man9
%endif

%if %{with_headers}
# Install kernel headers
make ARCH=%{hdrarch} INSTALL_HDR_PATH=$RPM_BUILD_ROOT/usr headers_install

# Manually go through the 'headers_check' process for every file, but
# don't die if it fails
chmod +x scripts/hdrcheck.sh
echo -e '*****\n*****\nHEADER EXPORT WARNINGS:\n*****' > hdrwarnings.txt
for FILE in `find $RPM_BUILD_ROOT/usr/include` ; do
    scripts/hdrcheck.sh $RPM_BUILD_ROOT/usr/include $FILE /dev/null >> hdrwarnings.txt || :
done
echo -e '*****\n*****' >> hdrwarnings.txt
if grep -q exist hdrwarnings.txt; then
   sed s:^$RPM_BUILD_ROOT/usr/include/:: hdrwarnings.txt
   # Temporarily cause a build failure if header inconsistencies.
   # exit 1
fi

# glibc provides scsi headers for itself, for now
rm -rf $RPM_BUILD_ROOT/usr/include/scsi
rm -f $RPM_BUILD_ROOT/usr/include/asm*/atomic.h
rm -f $RPM_BUILD_ROOT/usr/include/asm*/io.h
rm -f $RPM_BUILD_ROOT/usr/include/asm*/irq.h
%endif

%if %{with_bootwrapper}
make DESTDIR=$RPM_BUILD_ROOT bootwrapper_install WRAPPER_OBJDIR=%{_libdir}/kernel-wrapper WRAPPER_DTSDIR=%{_libdir}/kernel-wrapper/dts
%endif

###
### clean
###

%clean
rm -rf $RPM_BUILD_ROOT

###
### scripts
###

#
# This macro defines a %%post script for a kernel*-devel package.
#	%%kernel_devel_post <subpackage>
#
%define kernel_devel_post() \
%{expand:%%post -n %{variantbase}-%{?1:%{1}-}devel}\
if [ -f /etc/sysconfig/kernel ]\
then\
    . /etc/sysconfig/kernel || exit $?\
fi\
if [ "$HARDLINK" != "no" -a -x /usr/sbin/hardlink ]\
then\
    (cd /usr/src/kernels/%{KVERREL}%{?1:.%{1}} &&\
     /usr/bin/find . -type f | while read f; do\
       hardlink -c /usr/src/kernels/*.fc*.*/$f $f\
     done)\
fi\
%{nil}

# This macro defines a %%posttrans script for a kernel package.
#	%%kernel_variant_posttrans [-v <subpackage>] [-s <s> -r <r>] <mkinitrd-args>
# More text can follow to go at the end of this variant's %%post.
#
%define kernel_variant_posttrans(s:r:v:) \
%{expand:%%posttrans %{?-v:-n %{variantbase}-%{-v*}}}\
/sbin/new-kernel-pkg --package kernel%{?-v:-%{-v*}} --rpmposttrans %{KVERREL}%{?-v:.%{-v*}} || exit $?\
%{nil}

#
# This macro defines a %%post script for a kernel package and its devel package.
#	%%kernel_variant_post [-v <subpackage>] [-s <s> -r <r>] <mkinitrd-args>
# More text can follow to go at the end of this variant's %%post.
#
%define kernel_variant_post(s:r:v:) \
%{expand:%%kernel_devel_post %{?-v*}}\
%{expand:%%kernel_variant_posttrans %{?-v*}}\
%{expand:%%post -n %{variantbase}-%{?-v*}}\
%{-s:\
if [ `uname -i` == "x86_64" -o `uname -i` == "i386" ] &&\
   [ -f /etc/sysconfig/kernel ]; then\
  /bin/sed -i -e 's/^DEFAULTKERNEL=%{-s*}$/DEFAULTKERNEL=%{-r*}/' /etc/sysconfig/kernel || exit $?\
fi}\
/sbin/new-kernel-pkg --package kernel%{?-v:-%{-v*}} --mkinitrd --depmod --install %{*} %{KVERREL}%{?-v:.%{-v*}} || exit $?\
#if [ -x /sbin/weak-modules ]\
#then\
#    /sbin/weak-modules --add-kernel %{KVERREL}%{?-v*} || exit $?\
#fi\
%{nil}

#
# This macro defines a %%preun script for a kernel package.
#	%%kernel_variant_preun <subpackage>
#
%define kernel_variant_preun() \
%{expand:%%preun -n %{variantbase}%{?1:-%{1}}}\
/sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}%{?1:.%{1}} || exit $?\
#if [ -x /sbin/weak-modules ]\
#then\
#    /sbin/weak-modules --remove-kernel %{KVERREL}%{?1} || exit $?\
#fi\
%{nil}

%if %{with_up}
%kernel_variant_preun
%kernel_variant_post -s kernel-smp -r kernel
%endif

%if %{with_smp}
%kernel_variant_preun smp
%kernel_variant_post -v smp
%endif

%if %{with_pae}
%kernel_variant_preun PAE
%kernel_variant_post -v PAE -s kernel-smp -r kernel-PAE
%endif

%if %{with_debug}
%kernel_variant_preun debug
%kernel_variant_post -v debug
%endif

%if %{with_pae_debug}
%kernel_variant_post -v PAEdebug -s kernel-smp -r kernel-PAEdebug
%kernel_variant_preun PAEdebug
%endif

%if %{with_xen}
%kernel_variant_preun xen
%kernel_variant_post -v xen -s kernel-xen[0U] -r kernel-xen -- `[ -d /proc/xen -a ! -e /proc/xen/xsd_kva ] || echo --multiboot=/%{image_install_path}/xen.gz-%{KVERREL}.xen`
if [ -x /sbin/ldconfig ]
then
    /sbin/ldconfig -X || exit $?
fi
%endif

###
### file lists
###

%if %{with_headers}
%files -n %{mainpkgname}-headers
%defattr(-,root,root)
/usr/include/*
%endif

%if %{with_bootwrapper}
%files bootwrapper
%defattr(-,root,root)
/usr/sbin/*
%{_libdir}/kernel-wrapper
%endif

# only some architecture builds need kernel-doc
%if %{with_doc}
%files -n %{mainpkgname}-doc
%defattr(-,root,root)
%{_datadir}/doc/kernel-doc-%{kversion}/Documentation/*
%dir %{_datadir}/doc/kernel-doc-%{kversion}/Documentation
%dir %{_datadir}/doc/kernel-doc-%{kversion}
%{_datadir}/man/man9/*
%endif

# This is %{image_install_path} on an arch where that includes ELF files,
# or empty otherwise.
%define elf_image_install_path %{?kernel_image_elf:%{image_install_path}}

#
# This macro defines the %%files sections for a kernel package
# and its devel and debuginfo packages.
#	%%kernel_variant_files [-k vmlinux] [-a <extra-files-glob>] [-e <extra-nonbinary>] <condition> <subpackage>
#
%define kernel_variant_files(a:e:k:) \
%if %{1}\
%{expand:%%files -n %{variantbase}%{?2:-%{2}}}\
%defattr(-,root,root)\
/%{image_install_path}/%{?-k:%{-k*}}%{!?-k:vmlinuz}-%{KVERREL}%{?2:.%{2}}\
/boot/System.map-%{KVERREL}%{?2:.%{2}}\
#/boot/symvers-%{KVERREL}%{?2:.%{2}}.gz\
/boot/config-%{KVERREL}%{?2:.%{2}}\
%{?-a:%{-a*}}\
%dir /lib/modules/%{KVERREL}%{?2:.%{2}}\
/lib/modules/%{KVERREL}%{?2:.%{2}}/kernel\
/lib/modules/%{KVERREL}%{?2:.%{2}}/build\
/lib/modules/%{KVERREL}%{?2:.%{2}}/source\
/lib/modules/%{KVERREL}%{?2:.%{2}}/extra\
/lib/modules/%{KVERREL}%{?2:.%{2}}/updates\
/lib/modules/%{KVERREL}%{?2:.%{2}}/weak-updates\
%ifarch %{vdso_arches}\
/lib/modules/%{KVERREL}%{?2:.%{2}}/vdso\
%endif\
/lib/modules/%{KVERREL}%{?2:.%{2}}/modules.block\
/lib/modules/%{KVERREL}%{?2:.%{2}}/modules.networking\
/lib/modules/%{KVERREL}%{?2:.%{2}}/modules.order\
%ghost /boot/initrd-%{KVERREL}%{?2:.%{2}}.img\
%{?-e:%{-e*}}\
%{expand:%%files -n %{variantbase}-%{?2:%{2}-}devel}\
%defattr(-,root,root)\
%verify(not mtime) /usr/src/kernels/%{KVERREL}%{?2:.%{2}}\
/usr/src/kernels/%{KVERREL}%{?2:.%{2}}\
%if %{with_debuginfo}\
%ifnarch noarch\
%if %{fancy_debuginfo}\
%{expand:%%files -f debuginfo%{?2}.list -n %{variantbase}-%{?2:%{2}-}debuginfo}\
%else\
%{expand:%%files -n %{variantbase}-%{?2:%{2}-}debuginfo}\
%endif\
%defattr(-,root,root)\
%if !%{fancy_debuginfo}\
%if "%{elf_image_install_path}" != ""\
%{debuginfodir}/%{elf_image_install_path}/*-%{KVERREL}%{?2:.%{2}}.debug\
%endif\
%{debuginfodir}/lib/modules/%{KVERREL}%{?2:.%{2}}\
%{debuginfodir}/usr/src/kernels/%{KVERREL}%{?2:.%{2}}\
%endif\
%endif\
%endif\
%endif\
%{nil}


%kernel_variant_files %{with_up}
%kernel_variant_files %{with_smp} smp
%kernel_variant_files %{with_debug} debug
%kernel_variant_files %{with_pae} PAE
%kernel_variant_files %{with_pae_debug} PAEdebug
%kernel_variant_files -k vmlinux %{with_kdump} kdump
%kernel_variant_files -a /%{image_install_path}/xen*-%{KVERREL}.xen -e /etc/ld.so.conf.d/kernelcap-%{KVERREL}.xen.conf %{with_xen} xen

%changelog
* Fri Apr 25 2008 Mark McLoughlin <markmc@redhat.com>
- Fix x86_64 oops on reboot (ehabkost, #444025)

* Thu Apr 17 2008 Mark McLoughlin <markmc@redhat.com>
- Rebase to kernel-2_6_25-1_fc9

* Wed Apr 16 2008 Mark McLoughlin <markmc@redhat.com>
- Remove debugging printk/xen console hack

* Tue Apr 15 2008 Eduardo Habkost <ehabkost@redhat.com>
- Fix free_init_pages() to unmap pages from __START_KERNEL_map
  (bug #441543)
- Unpin and make pages read-write on pgd_free() (bug #441543)

* Mon Apr 14 2008 Mark McLoughlin <markmc@redhat.com>
- Rebase to kernel-2.6.25-0.228.rc9.fc9
- Include Markus's latest console handling patch

* Tue Apr  8 2008 Mark McLoughlin <markmc@redhat.com>
- Fix the requires on kernel-xen-debuginfo

* Tue Apr  8 2008 Mark McLoughlin <markmc@redhat.com>
- Some more pagetable-pinning fixes

* Mon Apr 07 2008 Mark McLoughlin <markmc@redhat.com>
- Small fixup to pagetable-pinning fix

* Mon Apr 07 2008 Eduardo Habkost <ehabkost@redhat.com>
- Add x86_64 pagetable-pinning fixes (bug #440587)

* Fri Apr  4 2008 Mark McLoughlin <markmc@redhat.com>
- Add patch from armbru to intelligently choose the preferred
  console (#434761)
- Couple of x86_64 fixes

* Thu Apr 03 2008 Eduardo Habkost <ehabkost@redhat.com>
- x86_64: Reserve kernel text and data segments at boot (bug #438000)

* Thu Apr  3 2008 Mark McLoughlin <markmc@redhat.com>
- x86_64 updates

* Wed Apr  2 2008 Mark McLoughlin <markmc@redhat.com>
- Update to kernel-2.6.25-0.187.rc8.fc9
- Use ".xen" suffix for some files instead of just "xen" (jwilson)

* Tue Apr  1 2008 Mark McLoughlin <markmc@redhat.com>
- Update to kernel-2_6_25-0_182_rc7_git6_fc9
- Fix oops when dlclose()ing some prelink libs (#436453)
- Drop the patch to make hvc0 the preferred console (#437706, #434761)

* Tue Mar 25 2008 Mark McLoughlin <markmc@redhat.com>
- Re-enable execshield (bug #434759)

* Thu Mar 20 2008 Mark McLoughlin <markmc@redhat.com>
- Make xen-blkfront module load wait until backend is
  connected; fixes intermittent boot failure (bug #436493)

* Thu Mar 13 2008 Eduardo Habkost <ehabkost@redhat.com>
- Temporary workaround for bug #437358: disable ia32 emulation

* Fri Mar 07 2008 Eduardo Habkost <ehabkost@redhat.com>
- Change PHYSICAL_START and SPARSEMEM_VMEMMAP on x86_64 .config, so
  it doesn't explode on boot

* Fri Mar  7 2008 Mark McLoughlin <markmc@redhat.com>
- Label everything in xen subpackage with %{kverrel}-xen to
  ensure xen-syms.debug goes into kernel-debuginfo-xen

* Wed Mar 05 2008 Mark McLoughlin <markmc@redhat.com>
- Reset to pv_ops xen DomU from kernel-2_6_25-0_93_rc4_fc9
- Revert the execshield patch for now
- Include xen pv fb and kbd drivers
- Add support for auto-probing frontend drivers
- Add module aliases for xennet and xenblk
- Add /proc/xen and /sys/hypervisor
- Add first round of x86_64 xen pv_ops patches

* Mon Feb 25 2008 Mark McLoughlin <markmc@redhat.com>
- Fix boot on x86_64 - gcc 4.3.0 related (#434556)

* Fri Feb 15 2008 Mark McLoughlin <markmc@redhat.com>
- Add e1000e driver (bug #360691)
- Fix build with new glibc

* Tue Feb 12 2008 Eduardo Habkost <ehabkost@redhat.com>
- CVE-2008-0600 fix (bug #432517)

* Fri Jan 18 2008 Daniel P. Berrange <berrange@redhat.com>
- Update to 3.2.0 final release

* Fri Jan 11 2008 Daniel P. Berrange <berrange@redhat.com>
- Rebuild due to koji build system failure

* Thu Jan 10 2008 Daniel P. Berrange <berrange@redhat.com>
- Update HV to 3.2.0 rc5 changeset 16701

* Mon Nov 19 2007 Eduardo Habkost <ehabkost@redhat.com>
- Re-add xen-hypervisor-abi provides. It was lost on the spec resync
  (problem detected on updates-testing)

* Wed Nov 14 2007 Eduardo Habkost <ehabkost@redhat.com>
- Update HV to official 3.1.0

* Mon Oct 29 2007  Eduardo Habkost <ehabkost@redhat.com>
- Pulled spec file from non-xen kernel
  - Enabled -debuginfo packages (bug #336351)

* Wed Oct 10 2007 Eduardo Habkost <ehabkost@redhat.com>
- Remove bogus WARN_ON() from synchronize_irq() (bug #293451)

* Mon Oct 08 2007 Eduardo Habkost <ehabkost@redhat.com>
- Add patch to fix BUG_ON() Oops caused by privcmd (bug #323031)

* Thu Sep 27 2007 Eduardo Habkost <ehabkost@redhat.com>
- Fix 3w-9xxx to use PCI resources properly and work under Xen (bug #309611)

* Wed Sep 26 2007 Eduardo Habkost <ehabkost@redhat.com>
- Disable Firewire on i686. It is not supported by the current
  Xen swiotlb implementation (bug #307461)

* Thu Sep 20 2007 Eduardo Habkost <ehabkost@redhat.com>
- Fix sleazy-fpu implementation to actually avoid on fpu-intensive
  programs

* Thu Sep 20 2007 Eduardo Habkost <ehabkost@redhat.com>
- Add fix for bug #294011 (floating point corruption)
  (changeset 8c24767501ff from Xen 3.1.1)

* Thu Sep 13 2007 Eduardo Habkost <ehabkost@redhat.com>
- Rebase to 2.6.21.7

* Thu Sep 13 2007 Eduardo Habkost <ehabkost@redhat.com>
- Fix for bug #248398: HVM domain hangs during (F-7) install.
  Backported fix from xen-unstable: 15239:656b8175f4f2

* Thu Sep 13 2007 Eduardo Habkost <ehabkost@redhat.com>
- Make hypervisor patches relative to the xen HG tree, not only the
  hypervisor subdirectory. This makes easier to import patches from
  upstream.

* Wed Sep 12 2007 Eduardo Habkost <ehabkost@redhat.com>
- Disable CONFIG_HIGHPTE. It is not reliable and cause performance loss
  under Xen.

* Thu Sep 06 2007 Eduardo Habkost <ehabkost@redhat.com>
- Include modules.block and modules.networking on the package (bug #280731)

* Thu Aug 30 2007 Eduardo Habkost <ehabkost@redhat.com>
- Provides: xen-hypervisor-abi = 3.1 (bug #269581)

* Wed Aug 29 2007 Eduardo Habkost <ehabkost@redhat.com>
- BuildRequires: /bin/awk. It is needed by Xen and not included
  on the default Koji buildroot anymore

* Mon Aug 27 2007 Eduardo Habkost <ehabkost@redhat.com>
- Disabled KVM on config files. It wouldn't work on kernel-xen and
  causes crashes when loaded

* Mon Aug 20 2007 Eduardo Habkost <ehabkost@redhat.com>
- Use %%if %%{includexen} around the xen-specific patches
- Add linux-2.6-xen-irq_vector-uninitialize.patch:
  Fix Xen IRQ handling bug that was introduced on the rebase
  to 2.6.21. It may fix some problems reported on bug #252301

* Thu Aug 09 2007 Eduardo Habkost <ehabkost@redhat.com>
- Add linux-2.6-xen-backwards-time.patch from linux-2.6.18-xen.hg
  changeset 87bb8705768a. This should fix bug #236307

* Tue Aug 07 2007 Eduardo Habkost <ehabkost@redhat.com>
- Re-add linux-2.6-disable-netback-checksum.patch. The other checksum
  patches are already included on linux-2.6-xen-3.1.0.patch.

* Mon Aug 06 2007 Eduardo Habkost <ehabkost@redhat.com>
- Xenoprof: fix DOMAIN_SWITCH_CODE value according to oprofile 0.9.3
  (Markus Armbruster)

* Tue Jul 24 2007 Eduardo Habkost <ehabkost@redhat.com>
- Rebase to 2.6.21.6

* Wed Jul 20 2007 Eduardo Habkost <ehabkost@redhat.com>
- Update xen patch to xen 3.1.0
- Remove old network checksum patches. They should be
  already included in the xen patch

* Tue Jul 17 2007 Eduardo Habkost <ehabkost@redhat.com>
- Make blkfront module wait for the disk to be added (bug #248462)
- Rebase to 2.6.20.14

* Thu Jul 12 2007 Eduardo Habkost <ehabkost@redhat.com>
- Remove #ifdef CONFIG_PM from acpi poweroff code (fix bug #241381)
- BuildRequires: python for xen buildsystem mkheader.py

* Mon Jun 11 2007 Eduardo Habkost <ehabkost@redhat.com>
- Added fix to bug #215201: linux-2.6-xen-fix-nosegneg-detection.patch
- Disabled CONFIG_PROVE_LOCKING, as the xen code doesn't support it.
  See bug #239601

* Tue May 22 2007 Eduardo Habkost <ehabkost@redhat.com>
- Add patch from bug #209429: linux-2.6-xen-iscsi-x86_64-no_iommu_init.patch

* Thu May 10 2007  <quintela@redhat.com>
- sync irq/manage.c with upstream (Markus).
- correctly init smpboot.c for xen (Chris Wright).
- pop %gs is a 2 bytes opcode (sct).

* Tue May  8 2007  <quintela@redhat.com>
- Disable kvm on xen kernels

* Fri May 04 2007 Eduardo Habkost <ehabkost@redhat.com>
- Updated Xen Hypervisor tarball to 3.1.0-rc7, hg cset 7041b52471c3

* Tue May 01 2007 Eduardo Habkost <ehabkost@redhat.com>
- Updated Xen Hypervisor to 3.0.5-rc4, hg cset 1668299c0ea4
- Added smp and vgetcpu fixes (bug #238015)
- Added patch from Heberter Xu, disabling checksum on netback,
  to work around problems with DHCP and partial checksums on guests

* Fri Apr 27 2007 Eduardo Habkost <ehabkost@redhat.com>
- Updated Xen Hypervisor to 3.0.5-rc3, hg cset 14934
- Included checksum patches to fix bug #223258

* Thu Mar 22 2007 Juan Quintela <quintela@redhat.com>
- disable alternative firewire stack for x86_64, it hangs kernel
  during boot.

* Thu Mar 22 2007 Juan Quintela <quintela@redhat.com>
- Add missing git-geode.patch.
- Re-enable Xen and update to 2.6.20-3.0.4 version.
- Update to 2.6.20.3.

* Mon Feb 12 2007 Kristian Høgsberg <krh@redhat.com>
- Update firewire patch with latest usptream changes.

* Mon Feb  5 2007 Dave Jones <davej@redhat.com>
- Fix attr2 corruption with btree data extents

* Sun Feb  4 2007 Dave Jones <davej@redhat.com>
- 2.6.20
- Move xen sources out of kernel-xen-devel. (Don Zickus)

* Sat Feb  3 2007 Dave Jones <davej@redhat.com>
- 2.6.20-rc7-git1

* Wed Jan 31 2007 Dave Jones <davej@redhat.com>
- 2.6.20rc7

* Tue Jan 30 2007 Dave Jones <davej@redhat.com>
- 2.6.20rc6-git2

* Mon Jan 29 2007 Chuck Ebbert <cebbert@redhat.com>
- 2.6.20rc6-git1

* Fri Jan 26 2007 Bill Nottingham <notting@redhat.com>
- turn on CONFIG_SYSFS_DEPRECATED so that things actually work. *sigh*

* Tue Jan 23 2007 Jeremy Katz <katzj@redhat.com>
- temporarily restore START_ARRAY ioctl for mdraid so that we can have mdraid
  in test1

* Sun Jan 14 2007 Roland McGrath <roland@redhat.com>
- utrace update: PTRACE_TRACEME fix

* Thu Jan 11 2007 Kristian Høgsberg <krh@redhat.com>
- Add and enable alternative firewire stack.

* Thu Jan 11 2007 Jeremy Katz <katzj@redhat.com>
- disable nmi watchdog by default

* Wed Jan 10 2007 Dave Jones <davej@redhat.com>
- 2.6.20rc4-git4
- PIIX3 PATA support.

* Sun Jan  7 2007 Dave Jones <davej@redhat.com>
- 2.6.20rc4

* Sat Jan  6 2007 Dave Jones <davej@redhat.com>
- 2.6.20rc3-git4

* Mon Jan  1 2007 Dave Jones <davej@redhat.com>
- 2.6.20rc3

* Mon Jan  1 2007 David Woodhouse <dwmw2@redhat.com>
- Fix fallout from half-baked upstream IBM vSCSI patch

* Mon Jan  1 2007 David Woodhouse <dwmw2@redhat.com>
- Fix BUG() in assembler in PowerPC
- Fix Maple IDE IRQ

* Sun Dec 31 2006 Dave Jones <davej@redhat.com>
- 2.6.20rc2-git2

* Fri Dec 29 2006 Dave Jones <davej@redhat.com>
- 2.6.20rc2-git1

* Fri Dec 29 2006 David Woodhouse <dwmw2@redhat.com>
- Update USB endianness patches

* Wed Dec 27 2006 Dave Jones <davej@redhat.com>
- 2.6.20rc2

* Thu Dec 21 2006 David Woodhouse <dwmw2@redhat.com>
- Fix IPv6 checksum handling
- Add MODULE_ALIAS() to pata_mpc52xx driver

* Wed Dec 20 2006 David Woodhouse <dwmw2@redhat.com>
- Fix BE OHCI support -- write only BE not BE and _then_ LE. Doh.

* Tue Dec 19 2006 David Woodhouse <dwmw2@redhat.com>
- Fix ebus oops
- Actually make it possible to include iSeries in the generic PPC64 kernel

* Tue Dec 19 2006 David Woodhouse <dwmw2@redhat.com>
- Include iSeries in the generic PPC64 kernel now that's possible
- Fix squashfs
- Fix softmac fallout from work_struct changes
- Update OF uevent handler patch

* Mon Dec 18 2006 David Woodhouse <dwmw2@redhat.com>
- Enable CONFIG_IDE on PowerPC, for PMAC. Need pata_pmac driver...
- Fix the deleteme handling
- Fix build on platforms without writel_be()
- Fix connector build failure

* Sun Dec 17 2006 Dave Jones <davej@redhat.com>
- 2.6.20rc1-git5

* Sun Dec 17 2006 David Woodhouse <dwmw2@redhat.com>
- Enable Efika platform support
- Temporarily provide __ucmpdi2 on ppc32 to work around GCC PR #25724

* Thu Dec 14 2006 Dave Jones <davej@redhat.com>
- 2.6.20rc1-git1
- libata: don't initialize sg in ata_exec_internal() if DMA_NONE

* Wed Dec 13 2006 Dave Jones <davej@redhat.com>
- Kill off -kdump for 686.

* Wed Dec 13 2006 David Woodhouse <dwmw2@redhat.com>
- Fix and re-enable ppc, ppc64, ppciseries builds
- Fix hdrcheck.sh invocation
- %%_target_cpu in BuildRoot to allow parallel builds

* Tue Dec 12 2006 Dave Jones <davej@redhat.com>
- 2.6.19-git19

* Tue Dec 12 2006 Dave Jones <davej@redhat.com>
- 2.6.19-git18

* Fri Dec  8 2006 Dave Jones <davej@redhat.com>
- 2.6.19-git12

* Thu Dec  7 2006 Dave Jones <davej@redhat.com>
- 2.6.19-git9

* Tue Dec  5 2006 David Woodhouse <dwmw2@redhat.com>
- Remove cell_defconfig update from Mambo patch
- Drop 64KiB CI page patch which is fixed differently upstream

* Tue Dec  5 2006 Dave Jones <davej@redhat.com>
- 2.6.19-git7

* Mon Dec  4 2006 Dave Jones <davej@redhat.com>
- 2.6.19-git5

* Wed Nov 29 2006 Dave Jones <davej@redhat.com>
- 2.6.19

* Mon Nov 27 2006 Dave Jones <davej@redhat.com>
- 2.6.19-rc6-git10

* Thu Nov 23 2006 David Woodhouse <dwmw2@redhat.com>
- Update Cell systemsim support (#217078)
- Fix utrace vs. Cell SPU (#217079)
- Enable Maple support

* Fri Nov 17 2006 Dave Jones <davej@redhat.com>
- 2.6.19rc6
- Merge squashfs changes from FC6.
- Disable W1

* Fri Nov 10 2006 Dave Jones <davej@redhat.com>
- Separate -debug kernels.

* Thu Nov  9 2006 Dave Jones <davej@redhat.com>
- 2.6.19rc5-git2
- Bump HZ to 1000

* Wed Nov  8 2006 Dave Jones <davej@redhat.com>
- 2.6.19rc5-git1

* Tue Nov  7 2006 Dave Jones <davej@redhat.com>
- 2.6.19rc5

* Mon Nov  6 2006 Dave Jones <davej@redhat.com>
- 2.6.19rc4-git11

* Tue Oct 31 2006 Dave Jones <davej@redhat.com>
- 2.6.19rc4

* Sun Oct 29 2006 Dave Jones <davej@redhat.com>
- 2.6.19rc3

* Fri Oct 13 2006 Dave Jones <davej@redhat.com>
- 2.6.19rc2
